package com.webonlineapp.hyjavaapexdemo;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import com.hyjavaapex.chart.Apexchart;
import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.Html;
import com.vaadin.flow.component.applayout.AppLayout;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.button.ButtonVariant;
import com.vaadin.flow.component.grid.Grid;
import com.vaadin.flow.component.html.H4;
import com.vaadin.flow.component.html.Span;
import com.vaadin.flow.component.icon.Icon;
import com.vaadin.flow.component.icon.VaadinIcon;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.tabs.Tab;
import com.vaadin.flow.component.textfield.TextArea;
import com.vaadin.flow.data.provider.ListDataProvider;
import com.vaadin.flow.data.renderer.ComponentRenderer;
import com.webonlineapp.hyjavaapexdemo.charts.DemoChart;
import com.webonlineapp.hyjavaapexdemo.charts.DemoChartBase;
import com.webonlineapp.hyjavaapexdemo.charts.DemoCharts;
import com.webonlineapp.hyjavaapexdemo.components.ApexchartComponent;
import com.webonlineapp.hyjavaapexdemo.components.ApexchartsImageComponent;
import com.webonlineapp.hyjavaapexdemo.components.JavaScriptComponent;
import com.webonlineapp.hyjavaapexdemo.components.JavaSourceComponent;
import com.webonlineapp.hyjavaapexdemo.components.PaperToggleButton;
import com.webonlineapp.hyjavaapexdemo.components.TabSheet;
import com.webonlineapp.hyjavaapexdemo.util.DesignerIcons;
import com.webonlineapp.hyjavaapexdemo.util.JavascriptUtil;

public class DemoPage {
	
	private TabSheet tabSheet = new TabSheet();
	VerticalLayout page1;
	private JavaSourceComponent page2 = new JavaSourceComponent();
	private JavaScriptComponent page3 = new JavaScriptComponent();
	private PaperToggleButton showMenu = new PaperToggleButton("Show Menu", true);
	
	private Component help = getHelpText();
	
	private String compHeight = "65vh";
	
	
	/**
	 * 
	 * @param view
	 * @param hyJavaImages
	 * @return
	 */
	public Component buildHeading(AppLayout view, boolean hyJavaImages) {
        H4 title = new H4((hyJavaImages ? 
        		com.hyjavacharts.hyjavaimages.LibraryInfo.getLibraryName() +
        		" v" + com.hyjavacharts.hyjavaimages.LibraryInfo.getHyJavaImagesAPIVersion()
        		: 
        		com.hyjavaapex.LibraryInfo.getLibraryName() + 
        		" v" + com.hyjavaapex.LibraryInfo.getHyJavaApexAPIVersion())
        		+ " Library Demonstration");
        title.getStyle().set("color", "white");
        
        return title;
	}
	
	/**
	 * 
	 * @param view
	 * @param hyJavaImages
	 * @return
	 */
	public Component buildMenu(AppLayout view, boolean hyJavaImages) {
		Grid<DemoChart> demoCharts = new Grid<DemoChart>();
        demoCharts.setHeight("100%");
        
        demoCharts.addColumn(new ComponentRenderer<>(demoChart -> {
            if (demoChart.isHeading()) {
                return new Html("<span style='font-size: larger;'><b><i>" + demoChart.getName() + "</i></b>" + 
                		(demoChart.isNewChart() ? 
                		"&nbsp;&nbsp;<img src='images/new.png' width='35' height='35'>" 
                		: "") +  
                		"</span>");
            } 
            else {
                return new Html("<span>" + "&nbsp;&nbsp;&nbsp;" + demoChart.getName() + 
                		(demoChart.isNewChart() ? 
                		"&nbsp;&nbsp;<img src='images/new.png' width='25' height='25'>" 
                		: "") + 
                		"</span>");
            }
        }));
        
        demoCharts.setItems(DemoCharts.getDemoChartsList());
        
        // Filter charts by display type
        ListDataProvider<DemoChart> dataProvider = (ListDataProvider<DemoChart>) demoCharts.getDataProvider();
        dataProvider.setFilter((dc) -> {
    		return dc.displayChart(hyJavaImages);
    	});
        
        demoCharts.addSelectionListener(event -> {
        	Optional<DemoChart> first = event.getFirstSelectedItem();
        	
        	if (first.isPresent()) {
         		DemoChart selectedDemoChart = first.get();
         		if (selectedDemoChart.getChart() != null) {
         			tabSheet.setSelectedIndex(0);

         			if (view.isOverlay()) {
         				view.setDrawerOpened(false);
         			}
         			
         			displayChart(selectedDemoChart.getChart(), selectedDemoChart.getName(), hyJavaImages);
          		}
        	}
        });
        
        if (hyJavaImages) {
        	demoCharts.select(DemoCharts.getDemoChartsList().get(1));
        }
        
        VerticalLayout options = new VerticalLayout();
        options.add(showMenu);

        showMenu.addValueChangeListener(e -> {
        	view.getElement().setAttribute("hide-menu", !e.getValue());
			JavascriptUtil.triggerResize();
		});
        
        VerticalLayout menu = new VerticalLayout();
        menu.setId("the-menu");
        menu.setWidthFull();
        menu.setHeight("100%");
        menu.setSpacing(false);
        menu.setPadding(false);
        
        menu.add(demoCharts, options);
        
        return menu;
	}
	
	/**
	 * 
	 * @param selectedDemoChart
	 * @param chartName
	 * @param hyJavaImages
	 */
	private void displayChart(DemoChartBase selectedDemoChart, String chartName, boolean hyJavaImages) {
		List<Apexchart> chartList = new ArrayList<Apexchart>();
		
		Apexchart apexchart = selectedDemoChart.configure();
		if (apexchart != null) {
			chartList.add(apexchart);
		}
		else {
			chartList = selectedDemoChart.getCharts();
		}

		String chartOptionsJs = "";
		String combinedChartOptionsJs = "";
		
		if (!hyJavaImages) {
			page1.getChildren().forEach(child -> { 
				if (child instanceof ApexchartComponent) {
					ApexchartComponent c = (ApexchartComponent) child;
					c.destroyChart();
				}
			});
		}
		page1.removeAll();
		
		if (hyJavaImages) {
			String[] chartOptionsJsArray = new String[chartList.size()];
			List<String> chartHeight = new ArrayList<String>();
			int i = 0;
			
			for (Apexchart chart : chartList) {
				chartOptionsJs = chart.chartOptionsToJs();
				combinedChartOptionsJs = combinedChartOptionsJs + chartOptionsJs;
				
				String ch = chart.getChartOptions().getChart().getHeightAsString();
				chartHeight.add(ch == null ? "100%" : ch);
				
				chartOptionsJsArray[i] = chartOptionsJs;
				i++;
			}
			
			ApexchartsImageComponent apexchartsImageComponent = new ApexchartsImageComponent();
			apexchartsImageComponent.setWidth("100%");
			apexchartsImageComponent.setHeight(compHeight);
			page1.add(apexchartsImageComponent);
			
			apexchartsImageComponent.setChartHeights(chartHeight);
			apexchartsImageComponent.displayChartImage(chartOptionsJsArray);
		}
		else {
			long chartId = 0;
			for (Apexchart chart : chartList) {
				chartOptionsJs = chart.chartOptionsToJs();
				combinedChartOptionsJs = combinedChartOptionsJs + chartOptionsJs;
				
				ApexchartComponent apexchartComponent = new ApexchartComponent();
				apexchartComponent.setChartId(chartId);
	 			apexchartComponent.setWidth("100%");
	 			
	 			page1.add(apexchartComponent);

	 			if (chartName.equals("Column With Group Label")) {
	 				apexchartComponent.setAdditionalJs("dayjs.extend(window.dayjs_plugin_quarterOfYear)");
	 			}
	 			else {
	 				apexchartComponent.setAdditionalJs("");
	 			}
	 			
	 			if (chartName.equals("Real Time")) {
	 				apexchartComponent.setChartId(200);
	 			}
	 			
				apexchartComponent.displayChart(chartOptionsJs);
				
				chartId++;
			}
			
			page2.setJavaSource(selectedDemoChart.getClass().getName());
		}
		
        page3.setJavaScript(combinedChartOptionsJs);
 	}
	
	/**
	 * 
	 * @param content
	 * @param hyJavaImages
	 */
	public void buildTab(VerticalLayout content, boolean hyJavaImages) {
		tabSheet = new TabSheet();
		tabSheet.setWidth("100%");

		// Add tabs and pages to tabsheet
		tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), new Icon(VaadinIcon.BAR_CHART), 
				new Span(hyJavaImages ? "Chart Image" : "Example Chart"), new Span(""))), buildPage1());
		
		if (!hyJavaImages) {
			tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), DesignerIcons.COFFEE_HOT.create(), 
					new Span("Java Source Code"), new Span(""))), buildPage2());
		}
		
		tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), new Icon(VaadinIcon.CURLY_BRACKETS), 
				new Span(hyJavaImages ? "ApexCharts Chart Options" : "Generated Chart Options"), new Span(""))), buildPage3());
		
		if (Properties.SHOW_TEST_TAB) {
			tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), new Icon(VaadinIcon.CHECK), 
					new Span("Test Chart Options"), new Span(""))), buildPage4());
		}
		
		// Add all tab components to the layout
        tabSheet.addComponentsToLayout(content);
        
        tabSheet.addSelectedChangeListener(event -> {
        	if (tabSheet.getSelectedIndex() == 1) {
        		page2.prettify();
        	}
        });
	}
	
	/**
	 * 
	 * @return
	 */
	private VerticalLayout buildPage1() {
		page1 = new VerticalLayout();
		page1.setHeight(compHeight);
		page1.setWidth("100%");
		page1.setMargin(false);
		
		page1.add(help);
        
        return page1;
	}
	
	/**
	 * 
	 * @return
	 */
	private JavaSourceComponent buildPage2() {
		page2.setHeight(compHeight);
		page2.setWidth("100%");
		
		return page2;
	}
	
	/**
	 * 
	 * @return
	 */
	private JavaScriptComponent buildPage3() {
		page3.setHeight(compHeight);
		page3.setWidth("100%");
		
		return page3;
	}
	
	/**
	 * 
	 * @return
	 */
	private VerticalLayout buildPage4() {
		VerticalLayout page4 = new VerticalLayout();
		
		TextArea chartOptions = new TextArea();
		chartOptions.setLabel("Chart Options");
		chartOptions.setClearButtonVisible(true);
		chartOptions.setPlaceholder("Paste chart options here...");
		chartOptions.setWidth("100%");
		chartOptions.setHeight("400px");
		
		Button displayButton = new Button("Display Chart");
		displayButton.addThemeVariants(ButtonVariant.LUMO_PRIMARY);
		
		ApexchartComponent highchartTest = new ApexchartComponent();
		highchartTest.setHeight(compHeight);
		highchartTest.setWidth("100%");
		
		page4.add(chartOptions);
		page4.add(displayButton);
		page4.add(highchartTest);

		displayButton.addClickListener(clickEvent -> {
			highchartTest.displayChart(chartOptions.getValue());
    	});

		return page4;
	}
	
	/**
	 * 
	 * @return
	 */
	private Component getHelpText() {
		HorizontalLayout hl = new HorizontalLayout();
		hl.setWidthFull();
		
		String text = 
			"<div><h4>" + com.hyjavaapex.LibraryInfo.getLibraryName() + 
			" v" + com.hyjavaapex.LibraryInfo.getHyJavaApexAPIVersion()
			+ " Library Demonstration" + "</h4>" + 
			"<p>To display an example chart, select one from the menu on the left.</p>" + 
			"<p>The Java source to configure the selected chart is shown in the <i>Java Source Code</i> tab." + 
			"<br>The ApexChart chart options generated from the library are shown in the <i>Generated Chart Options</i> tab.</p>" + 
			"</div>";
		
		hl.add(new Html(text));
		
		return hl;
	}

}
