package com.webonlineapp.hyjavaapexdemo.components;

import java.util.ArrayList;
import java.util.Base64;
import java.util.List;
import java.util.Random;

import com.hyjavacharts.hyjavaimages.ImageException;
import com.hyjavacharts.hyjavaimages.ImageFormat;
import com.hyjavacharts.hyjavaimages.ImageGenerator;
import com.hyjavacharts.hyjavaimages.ImageOptions;
import com.hyjavacharts.hyjavaimages.LibraryInfo;
import com.hyjavacharts.hyjavaimages.LibraryType;
import com.hyjavacharts.hyjavaimages.PdfOptions;
import com.vaadin.flow.component.Html;
import com.vaadin.flow.component.Tag;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.button.ButtonVariant;
import com.vaadin.flow.component.html.Image;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.radiobutton.RadioButtonGroup;
import com.vaadin.flow.component.radiobutton.RadioGroupVariant;
import com.vaadin.flow.server.StreamResource;

/**
 * Image generation is dependent on the HyJavaImages library.
 */

@Tag("div")
public class ApexchartsImageComponent extends VerticalLayout {
	private static final long serialVersionUID = 1L;
	
	private final int chartHeight = 600;
	private List<String> chartHeights = new ArrayList<String>();
	
	
	/**
	 * 
	 * @param chartOptionsJs
	 */
	public void displayChartImage(String... chartOptionsJs) {
		removeAll();
		
		add(getDemoText());
		
		RadioButtonGroup<String> imageFormatGroup = new RadioButtonGroup<>();
		imageFormatGroup.setLabel("Format");
		imageFormatGroup.setItems("png", "jpeg", "webp", "pdf");
		imageFormatGroup.addThemeVariants(RadioGroupVariant.LUMO_VERTICAL);
		imageFormatGroup.setValue("png");
		add(imageFormatGroup);
		
		RadioButtonGroup<String> resolutionGroup = new RadioButtonGroup<>();
		resolutionGroup.setLabel("Resolution");
		resolutionGroup.setItems("800 x 600", "1600 x 1200", "3200 x 2400");
		resolutionGroup.addThemeVariants(RadioGroupVariant.LUMO_VERTICAL);
		resolutionGroup.setValue("800 x 600");
		add(resolutionGroup);
		
		imageFormatGroup.addValueChangeListener(ComponentValueChangeEvent -> {
			if (imageFormatGroup.getValue().equals("pdf")) {
				resolutionGroup.setEnabled(false);
			}
			else {
				resolutionGroup.setEnabled(true);
			}
		});
		
		Button exportButton = new Button("Generate Chart Image");
		exportButton.addThemeVariants(ButtonVariant.LUMO_PRIMARY);
		add(exportButton);

		exportButton.addClickListener(clickEvent -> {
			Random rand = new Random();
			removeAll();

			boolean pdf = false;
			
			ImageFormat imageFormat = null;
			String format = imageFormatGroup.getValue();
			
			if (format.equals("png")) {
				imageFormat = ImageFormat.PNG;
			}
			else if (format.equals("jpeg")) {
				imageFormat = ImageFormat.JPEG;
			}
			else if (format.equals("webp")) {
				imageFormat = ImageFormat.WEBP;
			}
			else {
				pdf = true;
			}
			
			Number scale = 1;
			
			if (!pdf) {
				String resolution = resolutionGroup.getValue();
				if (resolution.equals("1600 x 1200")) {
					scale = 2;
				}
				else if (resolution.equals("3200 x 2400")) {
					scale = 4;
				}
			}

	        EmbeddedPdf chartPdf = null;
			Image chartImage = null;
			
			int height = chartHeight * Integer.parseInt(chartHeights.get(0).replace("%", "")) / 100;
			
    		ImageGenerator img = new ImageGenerator();
    		img.setChartDivSize("800px", height + "px");
    		img.setJavaScript(LibraryType.APEXCHARTS, "3.49.0");
    		img.setJavaScriptAdditional("https://cdn.jsdelivr.net/npm/moment@2.28.0",
    									"https://cdn.jsdelivr.net/npm/dayjs@1.11.0/dayjs.min.js", 
    									"https://cdn.jsdelivr.net/npm/dayjs@1.11.0/plugin/quarterOfYear.js");
    		img.setJavaScriptStatements("dayjs.extend(window.dayjs_plugin_quarterOfYear)");
    		
    		// the first element is always the main chart and the first to be displayed.
    		// if more than 1 set of charts, create an array of 2nd element and onwards.
    		// then use these in the setAdditionalChartOptions() method
    		if (chartOptionsJs.length > 1) {
	    		String[] chartOptionsJsArray = new String[chartOptionsJs.length - 1];
	    		String[] chartOptionsAttrArray = new String[chartOptionsJs.length - 1];
	    		for (int i = 1; i < chartOptionsJs.length; i++) {
	    			chartOptionsJsArray[i-1] = chartOptionsJs[i];
	    			int additionalHeight = chartHeight * Integer.parseInt(chartHeights.get(i).replace("%", "")) / 100;
	    			chartOptionsAttrArray[i-1] = "style=\"width: 800px; height: " + additionalHeight + "px;\"";
	    		}
	    		
	    		img.setAdditionalChartOptions(chartOptionsJsArray);
	    		img.setAdditionalChartDivAttributes(chartOptionsAttrArray);
    		}
    		
    		//img.setDebugHtmlDirectory("/var/chart-debug/");
    		
    		try {
    			String base64;
    			
    			if (pdf) {
    				base64 = img.toBase64PDF(chartOptionsJs[0], new PdfOptions().setLandscape(true).setScale(scale));
    				byte [] imageBytes = Base64.getDecoder().decode(base64);
    				StreamResource resource = new StreamResource("image" + rand.nextInt(999999999) + ".pdf", 
    	    				new ChartImageStream(imageBytes));
    				
    				chartPdf = new EmbeddedPdf(resource);
    			}
    			else {
    				base64 = img.toBase64Image(chartOptionsJs[0], 
    						new ImageOptions().setFormat(imageFormat).setScale(scale));
					byte [] imageBytes = Base64.getDecoder().decode(base64); 
					StreamResource resource = new StreamResource("image" + rand.nextInt(999999999) + 
							(imageFormat == ImageFormat.PNG ? ".png" : imageFormat == ImageFormat.JPEG ? ".jpeg" : ".webp"), 
		    				new ChartImageStream(imageBytes));
					
					chartImage = new Image(resource, "");
    			}
    			
 			} catch (ImageException e) {
				e.printStackTrace();
			}
     		
    		if (pdf) {
    			add(chartPdf);
    		}
    		else {
    			chartImage.setWidth("800px");
    			chartImage.setHeight(chartHeight + "px");
        		add(chartImage);
    		}
     	});
	}
	
	/**
	 * 
	 * @return
	 */
	private Html getDemoText() {
		String text = 
			"<div><h4>HyJavaImages v" + LibraryInfo.getHyJavaImagesAPIVersion() + " Library Demonstration</h4>" + 
			"<p>Select an example chart from the menu on the left and press the Generate Chart Image button.</p>" + 
			"<p>In this demo the <b>HyJavaImages</b> library generates the chart image from ApexCharts chart options displayed in the Chart Options tab above." + 
			"<br>All processing occurs on the server. No Javascript is executed on the client browser.</p></div>";
		
		return new Html(text);
	}

	/**
	 * 
	 * @param chartHeight
	 */
	public void setChartHeights(List<String> chartHeights) {
		this.chartHeights = chartHeights;
	}
	
}
