package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.DashStyle;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.TrackType;
import com.hyjavacharts.model.highcharts.series.SeriesLine;
import com.hyjavacharts.model.highcharts.sonification.GlobalContextTracks;
import com.hyjavacharts.model.highcharts.xaxis.PlotLines;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class BasicContextCues extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getTitle().setText("Helsinki Average Monthly Temperature")
			.setAlign(HorizontalAlign.LEFT).setMargin(25);

		YAxis yAxi = new YAxis();
	    yAxi.getPlotLinesSingle().setValue(0).setColor(new Color("#59D")).setDashStyle(DashStyle.SHORTDASH).setWidth(2);
		yAxi.setGridLineWidth(0).getTitle().setText("");
		yAxi.getLabels().setFormat("{text}°C");
		chartOptions.getYAxis().add(yAxi);

		XAxis xAxi = new XAxis();
		xAxi.getPlotBandsSingle().setFrom(3.5).setTo(8.5).setColor(new Color("#EEFFF4"))
			.getLabel().setText("Summer").setAlign(HorizontalAlign.LEFT).setX(10);
		xAxi.getPlotLines().add(new PlotLines().setValue(3.5).setColor(new Color("#4EA291")).setWidth(3));
		xAxi.getPlotLines().add(new PlotLines().setValue(8.5).setColor(new Color("#4EA291")).setWidth(3));
		xAxi.setCrosshair(true)
			.setCategories(Arrays.asList("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"));
		chartOptions.getXAxis().add(xAxi);
	
		chartOptions.getLegend().setEnabled(false);
		chartOptions.getTooltip().setValueSuffix("°C");
		
		SeriesLine seriesLine = new SeriesLine();
		seriesLine.setName("Helsinki").setColor(new Color("#2F2D2E"));
		seriesLine.setDataAsArrayNumber(Arrays.asList(-5, -6, -2, 4, 10, 14, 17, 15, 10, 6, 0, -4));
		chartOptions.getSeries().add(seriesLine);
	        
		chartOptions.getSonification().setDuration(8000)
			.getDefaultInstrumentOptions().getMapping().getPitchAsObject().setMin("c3").setMax("d6");
		
		GlobalContextTracks globalContextTracks = new GlobalContextTracks();
		globalContextTracks.setInstrument("piano").setValueInterval(0.33)
			.getMapping().setVolume(0.1).getPitchAsObject().setMapTo("y").setValue(0);
		chartOptions.getSonification().getGlobalContextTracks().add(globalContextTracks);
		
		globalContextTracks = new GlobalContextTracks();
		globalContextTracks.getActiveWhenAsObject().setMin(4).setMax(9).setProp("x");
		globalContextTracks.setInstrument("shaker").setValueInterval(100)
			.getMapping().setVolume(0.1);
		chartOptions.getSonification().getGlobalContextTracks().add(globalContextTracks);
		
		globalContextTracks = new GlobalContextTracks();
		globalContextTracks.getActiveWhenAsObject().setCrossingUp(4);
		globalContextTracks.setType(TrackType.SPEECH).setValueInterval(1)
			.getMapping().setText("Summer").setVolume(1);
		chartOptions.getSonification().getGlobalContextTracks().add(globalContextTracks);

		this.setAudio(true);
		
		return highChart;
	}

}
