package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.seriescolumn.Data;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class ColumnComparison extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
	    
		chartOptions.getChart().setType(ChartType.COLUMN);
		chartOptions.getTitle().setText("Summer Olympics 2016 - Top 5 countries by Gold medals").setAlign(HorizontalAlign.LEFT);
		chartOptions.getSubtitle().setText("Comparing to results from Summer Olympics 2016 - Source: <a href=\"https://olympics.com/en/olympic-games/tokyo-2020/medals\" target=\"_blank\">Olympics</a>")
			.setAlign(HorizontalAlign.LEFT);

		chartOptions.getPlotOptions().getColumn().setGrouping(false).setBorderWidth(0);
		chartOptions.getLegend().setEnabled(false);

		chartOptions.getTooltip()
			.setShared(true)
			.setHeaderFormat("<span style=\"font-size: 15px\">{point.point.name}</span><br/>")
			.setPointFormat("<span style=\"color:{point.color}\">\u25CF</span> {series.name}: <b>{point.y} medals</b><br/>");
		
		chartOptions.getExporting().setAllowHTML(true);
		
		XAxis xAxi = new XAxis();
		xAxi.setType(AxisType.CATEGORY).setMax(4)
			.getLabels().setUseHTML(true)//.setAnimate(true)
						.getFormatter().setFunctionBody("return '<span><img src=\"https://www.hyjavacharts.com/content/images/' + this.value + '.png\" style=\"width: 40px; height: 40px;\"/><br></span>'");
		chartOptions.getXAxis().add(xAxi);
		
		YAxis yAxi = new YAxis();
		yAxi.setShowFirstLabel(false).getTitle().setText("Gold medals");
		chartOptions.getYAxis().add(yAxi);
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.setName("2012").setColor(new Color().setRGB(158, 159, 163))
					.setPointPlacement(-0.2)
					.setLinkedTo("main")
					.setDataAsArrayObject(Arrays.asList(new Data().setName("Germany").setY(11),
														new Data().setName("Russia").setY(24),
														new Data().setName("China").setY(38),
														new Data().setName("Great Britain").setY(29),
														new Data().setName("United States").setY(47)));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setName("2016").setId("main").getDataSorting().setEnabled(true).setMatchByName(true);
		seriesColumn.getDataLabels().setEnabled(true).setInside(true).getStyle().setFontSize("16px");
		
		seriesColumn.setDataAsArrayObject(Arrays.asList(
				new Data().setName("Germany").setY(17).setColor(new Color("#FE6A35")),
				new Data().setName("Russia").setY(19).setColor(new Color("#6B8ABC")),
				new Data().setName("China").setY(26).setColor(new Color("#1C74BD")),
				new Data().setName("Great Britain").setY(27).setColor(new Color("#00A6A6")),
				new Data().setName("United States").setY(46).setColor(new Color("#D568FB"))));
		chartOptions.getSeries().add(seriesColumn);
		
		return highChart;
	}
	
}
