package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.Step;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.SeriesPie;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriespie.Data;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class ColumnLineAndPie extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getTitle()
			.setText("Sales of petroleum products March, Norway")
			.setAlign(HorizontalAlign.LEFT);
		
		XAxis xAxis = new XAxis();
		xAxis.setCategories(Arrays.asList("Jet fuel", "Duty-free diesel", "Petrol", "Diesel", "Gas oil"));
		chartOptions.getXAxis().add(xAxis);
		
		YAxis yAxis = new YAxis();
		yAxis.getTitle().setText("Million liters");
		chartOptions.getYAxis().add(yAxis);

		chartOptions.getTooltip().setValueSuffix(" million liters");
		
		chartOptions.getPlotOptions().getSeries().setBorderRadius("25%");
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.setType(SeriesType.COLUMN).setName("2020");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(59, 83, 65, 228, 184));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setType(SeriesType.COLUMN).setName("2021");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(24, 79, 72, 240, 167));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setType(SeriesType.COLUMN).setName("2022");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(58, 88, 75, 250, 176));
		chartOptions.getSeries().add(seriesColumn);

		SeriesSpline seriesline = new SeriesSpline();
		seriesline.setType(SeriesType.LINE).setStep(Step.CENTER).setName("Average");
		seriesline.getMarker()
			.setLineWidth(2)
			.setFillColor(new Color("white"))
			.getLineColor().setColorValue("Highcharts.getOptions().colors[3]");
		seriesline.setDataAsArrayNumber(Arrays.asList(47, 83.33, 70.66, 239.33, 175.66));
		chartOptions.getSeries().add(seriesline);

		SeriesPie seriesPie = new SeriesPie();
		seriesPie.setType(SeriesType.PIE)
			.setName("Total")
			.setCenterAsArrayNumber(Arrays.asList(75, 65))
			.setSize(100)
			.setInnerSize("70%")
			.setShowInLegend(false)
			.getDataLabels().setEnabled(false);
		
		Data d2020 = new Data()
			.setName("2020").setY(619).setColor(new Color().setColorValue("Highcharts.getOptions().colors[0]"));
		d2020.getDataLabels().setEnabled(true).setFormat("{point.total} M").getStyle().setFontSize("15px");
		d2020.getDataLabels().setDistance(-50);
		
		seriesPie.setDataAsArrayObject(Arrays.asList(
			d2020,
			new Data().setName("2021").setY(586).setColor(new Color().setColorValue("Highcharts.getOptions().colors[1]")),
			new Data().setName("2022").setY(647).setColor(new Color().setColorValue("Highcharts.getOptions().colors[2]"))
			));
		chartOptions.getSeries().add(seriesPie);
		
		return highChart;
	}

}
