package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.seriescolumn.Data;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class ColumnWithRotatedLabels extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.COLUMN);
		chartOptions.getTitle().setText("World's largest cities per 2021");
		chartOptions.getSubtitle().setText("Source: <a href=\"https://worldpopulationreview.com/world-cities\" target=\"_blank\">World Population Review</a>");

		XAxis xAxi = new XAxis();
		xAxi.setType(AxisType.CATEGORY)
			.getLabels().setAutoRotation(Arrays.asList(-45, -90))
			.getStyle().setFontSize("13px").setFontFamily("Verdana, sans-serif");
		chartOptions.getXAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.setMin(0)
			.getTitle().setText("Population (millions)");
		chartOptions.getYAxis().add(yAxi);
		
		chartOptions.getLegend().setEnabled(false);

		chartOptions.getTooltip()
			.setPointFormat("Population in 2021: <b>{point.y:.1f} millions</b>");

		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.setName("Population")
			.setColors(Arrays.asList(new Color("#9b20d9"), new Color("#9215ac"), new Color("#861ec9"), new Color("#7a17e6"), new Color("#7010f9"), new Color("#691af3"),
		            				 new Color("#6225ed"), new Color("#5b30e7"), new Color("#533be1"), new Color("#4c46db"), new Color("#4551d5"), new Color("#3e5ccf"),
		            				 new Color("#3667c9"), new Color("#2f72c3"), new Color("#277dbd"), new Color("#1f88b7"), new Color("#1693b1"), new Color("#0a9eaa"),
		            				 new Color("#03c69b"),  new Color("#00f194")))
			.setColorByPoint(true)
			.setGroupPadding(0)
			.getDataLabels()
				.setEnabled(true)
				.setRotation(-90)
				.setVerticalAlign(VerticalAlign.TOP)
				.setFormat("{point.y:.1f}")
				.setY(10)
				.getStyle().setFontSize("13px").setFontFamily("Verdana, sans-serif").setColor(new Color("#FFFFFF"));
		seriesColumn.setDataAsArrayObject(getSeriesData());
		chartOptions.getSeries().add(seriesColumn);
		
		return highChart;
	}
	
	/**
	 * 
	 * @return
	 */
	private ArrayList<Data> getSeriesData() {
		ArrayList<Data> array = new ArrayList<Data>();
		
		Object[] PopulationData = new Object[] { "Tokyo", 37.33,
									             "Delhi", 31.18,
									             "Shanghai", 27.79,
									             "Sao Paulo", 22.23,
									             "Mexico City", 21.91,
									             "Dhaka", 21.74,
									             "Cairo", 21.32,
									             "Beijing", 20.89,
									             "Mumbai", 20.67,
									             "Osaka", 19.11,
									             "Karachi", 16.45,
									             "Chongqing", 16.38,
									             "Istanbul", 15.41,
									             "Buenos Aires", 15.25,
									             "Kolkata", 14.974,
									             "Kinshasa", 14.970,
									             "Lagos", 14.86,
									             "Manila", 14.16,
									             "Tianjin", 13.79,
									             "Guangzhou", 13.64};
		
		for (int i = 0; i < PopulationData.length; i += 2) {
			array.add(new Data().setName((String) PopulationData[i]).setY((Number) PopulationData[i+1]));
		}

    	return array;
    }
}
