package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.SynthEnvelopePoint;
import com.hyjavacharts.model.common.SynthPatchEQFilter;
import com.hyjavacharts.model.common.SynthPatchOptions;
import com.hyjavacharts.model.common.SynthPatchOscillatorOptions;
import com.hyjavacharts.model.common.constants.SynthPatchOscillatorType;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesLine;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class CustomInstrument extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getTitle().setText("Custom instrument").setAlign(HorizontalAlign.LEFT).setMargin(25);
		chartOptions.getLegend().setEnabled(false);

		SeriesLine seriesLine = new SeriesLine();
		seriesLine.setDataAsArrayNumber(Arrays.asList(4, 5, 6, 5, 7, 8, 7, 9, 11, 13, 14, 11, 8, 7, 5, 2, 2, 1, 6, 8, 9, 11));
		chartOptions.getSeries().add(seriesLine);
		
		SynthPatchOptions synthPatchOptions = new SynthPatchOptions();
		synthPatchOptions.setMasterVolume(1).setNoteGlideDuration(0);
		synthPatchOptions.setMasterAttackEnvelope(Arrays.asList(
				new SynthEnvelopePoint().setT(1).setVol(0.5),
				new SynthEnvelopePoint().setT(17).setVol(1),
				new SynthEnvelopePoint().setT(32).setVol(0.85),
				new SynthEnvelopePoint().setT(76).setVol(0.7)));
		synthPatchOptions.setMasterReleaseEnvelope(Arrays.asList(
				new SynthEnvelopePoint().setT(1).setVol(0.7),
				new SynthEnvelopePoint().setT(34).setVol(0.2),
				new SynthEnvelopePoint().setT(119).setVol(0)));
		synthPatchOptions.setEq(Arrays.asList(
				new SynthPatchEQFilter().setFrequency(150).setQ(0.6).setGain(-12),
				new SynthPatchEQFilter().setFrequency(1000).setGain(-2),
				new SynthPatchEQFilter().setFrequency(2000).setGain(-16),
				new SynthPatchEQFilter().setFrequency(5000).setGain(8),
				new SynthPatchEQFilter().setFrequency(6000).setGain(10),
				new SynthPatchEQFilter().setFrequency(8000).setQ(0.8).setGain(12)));
		
		SynthPatchOscillatorOptions opt1 = new SynthPatchOscillatorOptions();
		opt1.setType(SynthPatchOscillatorType.SAWTOOTH).setVolume(1).setVolumePitchTrackingMultiplier(0.05);
		opt1.getLowpass().setFrequency(17).setFrequencyPitchTrackingMultiplier(100);
		opt1.getHighpass().setFrequency(200).setQ(3);
		
		SynthPatchOscillatorOptions opt2 = new SynthPatchOscillatorOptions();
		opt2.setType(SynthPatchOscillatorType.WHITENOISE).setVolume(0.2).setVmOscillator(0);
		opt2.getLowpass().setFrequency(4000).setQ(3);
		opt2.getHighpass().setFrequency(2000).setQ(3);
		
		synthPatchOptions.setOscillators(Arrays.asList(opt1, opt2));
		
		chartOptions.getSonification().setDuration(3000)
			.getDefaultInstrumentOptions().setInstrument(synthPatchOptions);
		
		this.setAudio(true);
		
		return highChart;
	}

}
