package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.General;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.ZoomType;
import com.hyjavacharts.model.highcharts.series.SeriesLine;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class LineChartWith500kPoints extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
	    
		chartOptions.getChart().setZoomType(ZoomType.X);
		
		chartOptions.getTitle().setText("Highcharts drawing 500,000 points").setAlign(HorizontalAlign.LEFT);
		chartOptions.getSubtitle().setText("Using the Boost module").setAlign(HorizontalAlign.LEFT);
		
		chartOptions.getAccessibility().getScreenReaderSection().setBeforeChartFormat("<{headingTagName}>{chartTitle}</{headingTagName}><div>{chartSubtitle}</div><div>{chartLongdesc}</div><div>{xAxisDescription}</div><div>{yAxisDescription}</div>");
		
		chartOptions.getTooltip().setValueDecimals(2);
		
		chartOptions.getXAxisSingle().setType(AxisType.DATETIME);
		
		SeriesLine seriesLine = new SeriesLine();
		seriesLine.setName("Hourly data points").setLineWidth(0.5);
		seriesLine.setDataAsJsValue(new General("data"));
		chartOptions.getSeries().add(seriesLine);
		
		this.setDemoJavaScript("function getData(n) {\r\n"
				+ "    const arr = [];\r\n"
				+ "    let i,\r\n"
				+ "        x,\r\n"
				+ "        a,\r\n"
				+ "        b,\r\n"
				+ "        c,\r\n"
				+ "        spike;\r\n"
				+ "    for (\r\n"
				+ "        i = 0, x = Date.UTC(new Date().getUTCFullYear(), 0, 1) - n * 36e5;\r\n"
				+ "        i < n;\r\n"
				+ "        i = i + 1, x = x + 36e5\r\n"
				+ "    ) {\r\n"
				+ "        if (i % 100 === 0) {\r\n"
				+ "            a = 2 * Math.random();\r\n"
				+ "        }\r\n"
				+ "        if (i % 1000 === 0) {\r\n"
				+ "            b = 2 * Math.random();\r\n"
				+ "        }\r\n"
				+ "        if (i % 10000 === 0) {\r\n"
				+ "            c = 2 * Math.random();\r\n"
				+ "        }\r\n"
				+ "        if (i % 50000 === 0) {\r\n"
				+ "            spike = 10;\r\n"
				+ "        } else {\r\n"
				+ "            spike = 0;\r\n"
				+ "        }\r\n"
				+ "        arr.push([\r\n"
				+ "            x,\r\n"
				+ "            2 * Math.sin(i / 100) + a + b + c + spike + Math.random()\r\n"
				+ "        ]);\r\n"
				+ "    }\r\n"
				+ "    return arr;\r\n"
				+ "}\r\n"
				+ "const n = 500000,\r\n"
				+ "    data = getData(n);"
				);
		
		return highChart;
	}
	
}
