package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Layout;
import com.hyjavacharts.model.highcharts.constants.Symbol;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class LineGraph extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
	    
		chartOptions.getChart()
			.setType(ChartType.SPLINE)
			.setBackgroundColor(new Color("#1b1b1b"))
			.setMarginBottom(40);
		
		chartOptions.getTitle()
			.setText("Top 10 largest economies by average values of GDP")
			.getStyle().setColor(new Color("#FFFFFF")).setFontWeight("bold");
		
		chartOptions.getSubtitle()
			.setText("Source: <a href=\"https://en.wikipedia.org/wiki/List_of_countries_by_largest_historical_GDP\" target=\"_blank\" style=\"color:white\">Wikipedia</a>")
			.setAlign(HorizontalAlign.LEFT)
			.getStyle().setColor(new Color("#FFFFFF")).setFontWeight("bold");

		YAxis yAxis = new YAxis();
		yAxis.setReversed(true).setGridLineWidth(0).setTickInterval(1).setStartOnTick(false).setEndOnTick(false)
			.getLabels().getStyle().setColor(new Color("#FFFFFF")).setFontWeight("bold");
		yAxis.getTitle().setText(null)
			.getStyle().setColor(new Color("#FFFFFF")).setFontWeight("bold");
		chartOptions.getYAxis().add(yAxis);
		
		XAxis xAxis = new XAxis();
		xAxis.setOpposite(true).setOffset(10)
			.getLabels().getStyle().setColor(new Color("#FFFFFF")).setFontWeight("bold");
		xAxis.getAccessibility().setRangeDescription("Range: 2010 to 2020");
		chartOptions.getXAxis().add(xAxis);
		
		chartOptions.getLegend()
			.setLayout(Layout.PROXIMATE).setAlign(HorizontalAlign.RIGHT).setVerticalAlign(VerticalAlign.MIDDLE)
			.getItemStyle().setColor(new Color("#FFFFFF")).setFontWeight("bold");
		
		chartOptions.getPlotOptions()
			.getSeries()
				.setPointStart(1980).setPointInterval(5).setLineWidth(4)
				.getMarker().setEnabled(false).setSymbol(Symbol.CIRCLE);
		chartOptions.getPlotOptions()
			.getSeries().getLabel().setConnectorAllowed(false);
		
		chartOptions.setColors(Arrays.asList(
				new Color("#FF0200"), new Color("#7CB4EC"), new Color("#008001"), new Color("#faf0be"), 
				new Color("#FFB6C1"), new Color("#2C908F"), new Color("#91EE7D"), new Color("#F7A35B"), 
				new Color("#8185E8"), new Color("#F15C80"), new Color("#ffffff"), new Color("#A19642")));
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.setName("China").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(10, 9, 7, 3, 2, 2, 2, 1, 1));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("USA").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(1, 2, 1, 1, 1, 1, 1, 2, 2));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("India").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(9, 10, 10, 5, 5, 4, 3, 3, 3));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Germany").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(4, 4, 4, 4, 4, 5, 5, 5, 5));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Japan").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(3, 3, 3, 2, 3, 3, 4, 4, 4));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Russia").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(null, null, null, 6, 7, 6, 6, 6, 6));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Indonesia").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(null, null, null, null, null, null, null, 8, 7));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Brazil").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(7, 7, 9, 9, 9, 7, 7, 7, 8));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("France").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(6, 6, 6, 8, 6, 8, 8, 10, 9));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("UK").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(8, 8, 8, 10, 10, 9, 9, 9, 10));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Soviet Union").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(2, 1, 2, null));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Italy").getLabel().setEnabled(false);
		seriesSpline.setDataAsArrayNumber(Arrays.asList(5, 5, 5, null));
		chartOptions.getSeries().add(seriesSpline);
		
		return highChart;
	}
	
}
