package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Overflow;
import com.hyjavacharts.model.highcharts.series.SeriesDumbbell;
import com.webonlineapp.hyjavachartsdemo11.chartdata.DumbbellData;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class LowerAndUpperDumbbellMarkers extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.DUMBBELL).setInverted(true);
		chartOptions.getTitle().setText("Change in Card Usage");
		chartOptions.getSubtitle().setText("Season 21 vs Season 22 <br>Top 1000");
		
		chartOptions.getTooltip().setShared(true).setPointFormat("Season 21: used in deck by <strong>{point.previous}</strong> of 1000 top players<br>Season 22: used in deck by <strong>{point.current}</strong> of 1000 top players");
		
		chartOptions.getXAxisSingle().setType(AxisType.CATEGORY).setOpposite(true);
		chartOptions.getYAxisSingle().getTitle().setText("");
		chartOptions.getLegend().setEnabled(false);
		
		chartOptions.getPlotOptions().getDumbbell().setConnectorWidth(3).getMarker().setRadius(5).getStates().getHover().setLineWidth(0);
		chartOptions.getPlotOptions().getDumbbell().getDataLabels()
			.setEnabled(true).setColor(new Color("contrast")).setCrop(false).setOverflow(Overflow.ALLOW);
		
		DumbbellData seriesData = new DumbbellData();
		SeriesDumbbell seriesDumbbell = new SeriesDumbbell();
		seriesDumbbell.setName("Increase").setColor(chartOptions.getColors().get(2));
		seriesDumbbell.getMarker().setEnabled(true).setSymbol("triangleRight");
		seriesDumbbell.getLowMarker().setEnabled(false);
		
		seriesDumbbell.setDataAsJsValue(seriesData.getIncreasingData());
		chartOptions.getSeries().add(seriesDumbbell);
		
		seriesDumbbell = new SeriesDumbbell();
		seriesDumbbell.setName("Decrease").setColor(chartOptions.getColors().get(5)).setLowColor(new Color().setColorValue("undefined"));
		seriesDumbbell.getMarker().setEnabled(false);
		seriesDumbbell.getLowMarker().setEnabled(true).setSymbol("triangleLeft");
		seriesDumbbell.setDataAsJsValue(seriesData.getDecreasingData());
		chartOptions.getSeries().add(seriesDumbbell);
		
		this.setDemoJavaScript("Highcharts.SVGRenderer.prototype.symbols.triangleLeft = (x, y, w, h) =>\r\n"
				+ "    ['M', x, y + h / 2, 'L', x + w, y, 'L', x + w, y + h, 'Z'];\r\n"
				+ "\r\n"
				+ "Highcharts.SVGRenderer.prototype.symbols.triangleRight = (x, y, w, h) =>\r\n"
				+ "    ['M', x + w, y + h / 2, 'L', x, y, 'L', x, y + h, 'Z'];");
		
		return highChart;
	}
	
}
