package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.ArrayList;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.RadialGradient;
import com.hyjavacharts.model.common.Stop;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Cursor;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesPie;
import com.hyjavacharts.model.highcharts.series.seriespie.Data;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class PieWithGradientFill extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
				
		chartOptions.getChart().setType(ChartType.PIE).setPlotBackgroundColor(null).setBorderWidth(null).setPlotShadow(false);
		
		chartOptions.getTitle().setText("Registered private vehicles in Norway, by type of fuel, 2020").setAlign(HorizontalAlign.LEFT);
		chartOptions.getTooltip().setPointFormat("{series.name}: <b>{point.percentage:.1f}%</b>");
		
		chartOptions.getAccessibility().getPoint().setValueSuffix("%");
		
		chartOptions.getPlotOptions()
			.getPie()
				.setAllowPointSelect(true)
				.setCursor(Cursor.POINTER)
				.getDataLabels()
					.setEnabled(true)
					.setConnectorColor(new Color(128, 128, 128, 0.5))
					.setFormat("<span style=\"font-size: 1.2em\"><b>{point.name}</b></span><br><span style=\"opacity: 0.6\">{point.percentage:.1f} %</span>");
		
		SeriesPie seriesPie = new SeriesPie();
		seriesPie.setName("Share");
		seriesPie.setDataAsArrayObject(getSeriesData());
		chartOptions.getSeries().add(seriesPie);
		
		chartOptions.setColors(getNewColors(chartOptions));
		
		return highChart;
	}
	
	/**
	 * 
	 * @return
	 */
	private ArrayList<Data> getSeriesData() {
		ArrayList<Data> array = new ArrayList<Data>();

		array.add(new Data().setName("Petrol").setY(938899));
		array.add(new Data().setName("Diesel").setY(1229600));
		array.add(new Data().setName("Electricity").setY(325251));
		array.add(new Data().setName("Other").setY(238751));
		
		return array;
    }
	
	/**
	 * Create new colors list
	 * 
	 * @param chartOptions
	 * @return
	 */
	private List<Color> getNewColors(ChartOptions chartOptions) {
		List<Color> newColors = new ArrayList<Color>();

		for (Color defaultColor : chartOptions.getColors()) {
			ArrayList<Stop> stops = new ArrayList<Stop>();
			stops.add(new Stop(0, new Color(defaultColor.getColor())));
			stops.add(new Stop(1, new Color(defaultColor.getColor()).brighten(-0.3)));
			
			newColors.add(new Color(new RadialGradient(0.5,  0.3, 0.7), stops));
		}
		
		return newColors;
	}
}
