package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.General;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.ZoomType;
import com.hyjavacharts.model.highcharts.series.SeriesScatter;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class ScatterPlotWith1MPoints extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.getChart().setType(ChartType.SCATTER).setZoomType(ZoomType.XY);
		chartOptions.getTitle().setText("Scatter chart with 1 million points").setAlign(HorizontalAlign.LEFT);
		
		chartOptions.getLegend().setEnabled(false);
		chartOptions.getBoost().setUseGPUTranslations(true).setUsePreallocated(true);

		chartOptions.getXAxisSingle().setMin(0).setMax(100).setGridLineWidth(1);
		chartOptions.getYAxisSingle().setMin(0).setMax(100).setMinPadding(0).setMaxPadding(0).getTitle().setText(null);

		chartOptions.getAccessibility().getScreenReaderSection().setBeforeChartFormat("<{headingTagName}>{chartTitle}</{headingTagName}><div>{chartLongdesc}</div><div>{xAxisDescription}</div><div>{yAxisDescription}</div>");

		SeriesScatter seriesScatter = new SeriesScatter();
		seriesScatter.setType(SeriesType.SCATTER).setColor(new Color(152,0,67,0.1));
		seriesScatter.getMarker().setRadius(0.5);
		seriesScatter.getTooltip().setFollowPointer(false).setPointFormat("[{point.x:.1f}, {point.y:.1f}]");
		seriesScatter.setDataAsJsValue(new General("data"));
		chartOptions.getSeries().add(seriesScatter);
		
		this.setDemoJavaScript("const data = [],\r\n"
				+ "    n = 1000000;\r\n"
				+ "\r\n"
				+ "// Generate and position the datapoints in a tangent wave pattern\r\n"
				+ "for (let i = 0; i < n; i += 1) {\r\n"
				+ "    const theta = Math.random() * 2 * Math.PI;\r\n"
				+ "    const radius = Math.pow(Math.random(), 2) * 100;\r\n"
				+ "\r\n"
				+ "    const waveDeviation = (Math.random() - 0.5) * 70;\r\n"
				+ "    const waveValue = Math.tan(theta) * waveDeviation;\r\n"
				+ "\r\n"
				+ "    data.push([\r\n"
				+ "        50 + (radius + waveValue) * Math.cos(theta),\r\n"
				+ "        50 + (radius + waveValue) * Math.sin(theta)\r\n"
				+ "    ]);\r\n"
				+ "}\r\n"
				+ "\r\n"
				);
		
		return highChart;
	}
	
}
