package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.ArrayList;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.SonificationOrder;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class Simultaneously extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getTitle().setText("Series sonified simultaneously")
			.setAlign(HorizontalAlign.LEFT).setMargin(25);
		
		chartOptions.getSubtitle().setText("Earcon when finished")
			.setAlign(HorizontalAlign.LEFT);
	
		chartOptions.getTooltip().setShared(true).setValueDecimals(3);

		chartOptions.getPlotOptions().getSeries().getMarker().setEnabled(false);

		chartOptions.getXAxisSingle().getCrosshairAsObject().setWidth(3).setColor(new Color("#9088b0"));
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.setType(SeriesType.SPLINE).setDataAsArrayNumber(getDataSeries1());
		seriesSpline.getSonification().getTracksSingle().setInstrument("flute").getMapping().setPan(-1);
		chartOptions.getSeries().add(seriesSpline);
	        
		seriesSpline = new SeriesSpline();
		seriesSpline.setType(SeriesType.SPLINE).setDataAsArrayNumber(getDataSeries2());
		seriesSpline.getSonification().getTracksSingle().setInstrument("piano").getMapping().setPan(1);
		chartOptions.getSeries().add(seriesSpline);
		
		chartOptions.getSonification().setOrder(SonificationOrder.SIMULTANEOUS).setDuration(4000)
			.getEvents().setOnEnd(new Function("var s = e.chart.sonification; s.playNote('vibraphone', { note: 'G4' }); s.playNote('vibraphone', { note: 'C4', pan: -1 }); s.playNote('vibraphone', { note: 'E4', pan: 0 }, 200); s.playNote('vibraphone', { note: 'C5', pan: 1 }, 400);", "e"));
		
		this.setAudio(true);
		
		return highChart;
	}
	
	/**
	 * 
	 * @return
	 */
	private List<Number> getDataSeries1() {
		List<Number> data = new ArrayList<Number>();
		
        for (double i = 0; i < 100; ++i) {
        	data.add(Math.sin(i / 30) * 5);
        }
        
        return data;
	}
	
	/**
	 * 
	 * @return
	 */
	private List<Number> getDataSeries2() {
		List<Number> data = new ArrayList<Number>();
		
        for (double i = 0; i < 100; ++i) {
            data.add(Math.sin((i + 30) / 20) * 6);
        }
        
        return data;
	}

}
