package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Stacking;
import com.hyjavacharts.model.highcharts.constants.Symbol;
import com.hyjavacharts.model.highcharts.constants.TickmarkPlacement;
import com.hyjavacharts.model.highcharts.series.SeriesAreaspline;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class StackedInvertedArea extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.AREASPLINE).setInverted(true);
		
		chartOptions.setColors(Arrays.asList(new Color("#331E36"), new Color("#41337A"), new Color("#6EA4BF"), new Color("#98CAD5"), 
											 new Color("#C2EFEB"), new Color("#ECFEE8"), new Color("#ECFEE8")));
		
		chartOptions.getTitle().setText("MSIS atmospheric composition by height").setAlign(HorizontalAlign.LEFT);
		chartOptions.getSubtitle()
			.setText("Source: <a href=\"https://en.wikipedia.org/wiki/Atmosphere_of_Earth\" target=\"_blank\">Wikipedia.org</a>")
			.setAlign(HorizontalAlign.LEFT);
        
		chartOptions.getXAxisSingle().setTickmarkPlacement(TickmarkPlacement.ON).setOpposite(true).setReversed(false).setCrosshair(true)
			.getTitle().setText("Height (km)");
		
		chartOptions.getYAxisSingle().setReversedStacks(false).getTitle().setText("Volume fraction");
		chartOptions.getYAxisSingle().getLabels().setFormat("{value} %");

		chartOptions.getTooltip().setShared(true)
			.setHeaderFormat("<table>")
			.setPointFormat("<tr><td><span style=\"color:{series.color};\">\u2b24</span></td><td>{series.name}</td><td style=\"text-align: right\"><b>{point.y} %</b></td></tr>")
			.setFooterFormat("</table>")
			.setUseHTML(true);
		
		chartOptions.getPlotOptions().getAreaspline()
			.setStacking(Stacking.PERCENT).setLineColor(new Color("#666666")).setPointInterval(100).setLineWidth(1)
			.getMarker().setEnabled(false).setSymbol(Symbol.CIRCLE)
			.setFillColor(new Color("#666666")).setLineColor(new Color("#666666")).setRadius(1);
		chartOptions.getPlotOptions().getAreaspline().getLabel().getStyle().setFontSize("16px");
		chartOptions.getPlotOptions().getAreaspline().getStates().getHover().getHalo().setSize(0);
		
		SeriesAreaspline seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.setName("N2").setDataAsArrayNumber(Arrays.asList(78, 76, 38, 10, 2.5, 0, 0, 0, 0, 0, 0));
		chartOptions.getSeries().add(seriesAreaspline);
		
		seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.setName("O2").setDataAsArrayNumber(Arrays.asList(21, 20, 2, 0.5, 0, 0, 0, 0, 0, 0, 0));
		chartOptions.getSeries().add(seriesAreaspline);
		
		seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.setName("O").setDataAsArrayNumber(Arrays.asList(0, 3, 59, 84, 70, 32, 8, 3, 1, 0, 0));
		chartOptions.getSeries().add(seriesAreaspline);
		
		seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.setName("Ar").setDataAsArrayNumber(Arrays.asList(1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0));
		chartOptions.getSeries().add(seriesAreaspline);
		
		seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.setName("He").setDataAsArrayNumber(Arrays.asList(0, 0, 1, 5, 25, 62, 82, 82, 78, 71, 62));
		chartOptions.getSeries().add(seriesAreaspline);
		
		seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.setName("H").setDataAsArrayNumber(Arrays.asList(0, 0, 0, 0.5, 2.5, 6, 10, 15, 21, 29, 38));
		chartOptions.getSeries().add(seriesAreaspline);
		
		this.setWidth("400px");
		
		return highChart;
	}

}
