package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Stacking;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class StackedPercentageColumn extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.COLUMN);
		chartOptions.getTitle().setText("Domestic passenger transport by mode of transport, Norway").setAlign(HorizontalAlign.LEFT);
		chartOptions.getSubtitle()
			.setText("Source: <a href=\"https://www.ssb.no/transport-og-reiseliv/landtransport/statistikk/innenlandsk-transport\">SSB</a>")
			.setAlign(HorizontalAlign.LEFT);

		XAxis xAxi = new XAxis();
		xAxi.setCategories(Arrays.asList("2019", "2020", "2021"));
		chartOptions.getXAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.setMin(0)
			.getTitle().setText("Percent");
		chartOptions.getYAxis().add(yAxi);

		chartOptions.getTooltip()
			.setPointFormat("<span style=\"color:{series.color}\">{series.name}</span>: <b>{point.y}</b> ({point.percentage:.0f}%)<br/>")
			.setShared(true);
		
		chartOptions.getPlotOptions().getColumn()
			.setStacking(Stacking.PERCENT)
			.getDataLabels().setEnabled(true).setFormat("{point.percentage:.0f}%");

		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.setName("Road");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(434, 290, 307));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setName("Rail");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(272, 153, 156));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setName("Air");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(13, 7, 8));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setName("Sea");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(55, 35, 41));
		chartOptions.getSeries().add(seriesColumn);
		
		return highChart;
	}
	
}
