package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.common.sonification.Tracks;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.Cursor;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.LandmarkVerbosity;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.TrackType;
import com.hyjavacharts.model.highcharts.series.SeriesBoxplot;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class AudioBoxplot extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getTitle().setText("Exam scores per class").setAlign(HorizontalAlign.LEFT).setMargin(30);
		chartOptions.getSubtitle().setText("Click each box to sonify on its own").setAlign(HorizontalAlign.LEFT);
		chartOptions.getLegend().setEnabled(false);
		
		chartOptions.getAccessibility().setLandmarkVerbosity(LandmarkVerbosity.ONE);
		
		chartOptions.getData().setCsv(getData());
		
		//chartOptions.getXAxisSingle().getCrosshairAsObject().setEnabled(true);	//api ?

		chartOptions.getYAxisSingle().setMax(100).setTickInterval(25).getTitle().setEnabled(false);
		chartOptions.getYAxisSingle().getLabels().setFormat("{text}%");

		chartOptions.getTooltip().setFollowPointer(true);

		SeriesBoxplot seriesBoxplot = new SeriesBoxplot();
		seriesBoxplot.setType(SeriesType.BOXPLOT)
			.setName("Exam scores").setMedianWidth(3).setColorByPoint(true)
			.setStickyTracking(true).setCursor(Cursor.POINTER)
			.getEvents().setClick(new Function("e.point.sonify();", "e"));
		seriesBoxplot.getSonification().getDefaultInstrumentOptions().getMapping()
			.getPitchAsObject().setMin("d2").setMax("c7");
		
		Tracks track = new Tracks().setType(TrackType.SPEECH);
		track.getMapping().setText("{point.name}").setRate(2).setVolume(1);
		seriesBoxplot.getSonification().getTracks().add(track);
		
		track = new Tracks();
		track.getMapping().setPlayDelay(1300).getPitchAsObject().setMapTo("low");
		seriesBoxplot.getSonification().getTracks().add(track);
		
		track = new Tracks();
		track.getMapping().setPlayDelay(1420).getPitchAsObject().setMapTo("q1");
		seriesBoxplot.getSonification().getTracks().add(track);
		
		track = new Tracks();
		track.getMapping().setPlayDelay(1540).getPitchAsObject().setMapTo("median");
		seriesBoxplot.getSonification().getTracks().add(track);
		
		track = new Tracks();
		track.getMapping().setPlayDelay(1660).getPitchAsObject().setMapTo("q3");
		seriesBoxplot.getSonification().getTracks().add(track);
		
		track = new Tracks();
		track.getMapping().setPlayDelay(1780).getPitchAsObject().setMapTo("high");
		seriesBoxplot.getSonification().getTracks().add(track);
		
		chartOptions.getSeries().add(seriesBoxplot);

		chartOptions.getSonification().setDuration(22000).setShowTooltip(false);

		this.setAudio(true);
		
		return highChart;
	}
	
	/**
	 * 
	 * @return
	 */
	private String getData() {
		return "Class ID,Minimum,First quartile,Median,Third quartile,Maximum\r\n"
				+ "MATH101,40,65,75,85,100\r\n"
				+ "BIOL102,45,74,80,85,98\r\n"
				+ "CHEM103,50,64,78,82,96\r\n"
				+ "PHYS104,42,65,77,91,100\r\n"
				+ "PSYC105,48,70,81,89,94\r\n"
				+ "ECON106,46,67,79,92,97\r\n"
				+ "COMP107,43,77,83,95,99\r\n"
				+ "ENGL108,55,74,85,96,100\r\n"
				+ "HIST109,60,78,86,97,100\r\n"
				+ "STAT110,52,71,82,91,93";
	}

}
