package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.DashStyle;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.ZoomType;
import com.hyjavacharts.model.highcharts.series.SeriesArearange;
import com.webonlineapp.hyjavachartsdemo11.chartdata.AreaRangeData;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class FanChart extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.AREARANGE)
			.getZooming().setType(ZoomType.X);
		
		chartOptions.getTitle().setText("EU GDP");
		chartOptions.getSubtitle().setText("<a href=\"https://economy-finance.ec.europa.eu/system/files/2023-05/SF_2023_Statistical%20Annex.pdf\" target=\"_blank\">European Economic Forecast, Spring 2023</a>");

		chartOptions.getXAxisSingle().setType(AxisType.CATEGORY).setMin(1).setMax(12).setEndOnTick(false)
			.getAccessibility().setRangeDescription("Range: 2022 to 2024.");
		chartOptions.getXAxisSingle().getPlotBandsSingle().setColor(new Color().setRGBA(255, 75, 66, 0.07))
			.setFrom(5.5).setTo(99).getLabel().setText("Forecast");
		chartOptions.getXAxisSingle().getPlotLinesSingle().setDashStyle(DashStyle.DASH)
			.setColor(chartOptions.getColors().get(4)).setWidth(2).setValue(5.5);
		
		chartOptions.getYAxisSingle().setOpposite(true).setMax(30).getTitle().setText("GDP change<br/>on preceding year");
		chartOptions.getYAxisSingle().getLabels().setFormat("{value}%");
		
		chartOptions.getTooltip().setCrosshairs(true).setShared(true).setValueSuffix("%").setValuePrefix("+");
		
		chartOptions.getResponsive().getRulesSingle().getChartOptions().getXAxisSingle().getLabels().setStaggerLines(2);
		chartOptions.getResponsive().getRulesSingle().getCondition().setMinWidth(540);
		
		chartOptions.getLegend().setEnabled(false);
		
		chartOptions.getPlotOptions().getSeries().getMarker().setEnabled(false);
		chartOptions.getPlotOptions().getArearange().setEnableMouseTracking(false).setColor(chartOptions.getColors().get(7))
			.setFillOpacity(0.33).setLineWidth(0).getStates().getInactive().setEnabled(false);

		SeriesArearange seriesArearange = new SeriesArearange();
		seriesArearange.setName("EU GDP").setType(SeriesType.LINE).setZIndex(2).setColor(chartOptions.getColors().get(7)).setLineWidth(4);
		seriesArearange.getDataAsJsValue().setJsValue(new AreaRangeData().getFan(1));
		chartOptions.getSeries().add(seriesArearange);
		
		seriesArearange = new SeriesArearange();
		seriesArearange.setName("1σ");
		seriesArearange.getDataAsJsValue().setJsValue(new AreaRangeData().getFan(2));
		chartOptions.getSeries().add(seriesArearange);
		
		seriesArearange = new SeriesArearange();
		seriesArearange.setName("2σ");
		seriesArearange.getDataAsJsValue().setJsValue(new AreaRangeData().getFan(3));
		chartOptions.getSeries().add(seriesArearange);
		
		seriesArearange = new SeriesArearange();
		seriesArearange.setName("3σ");
		seriesArearange.getDataAsJsValue().setJsValue(new AreaRangeData().getFan(4));
		chartOptions.getSeries().add(seriesArearange);
		
		return highChart;
	}

}
