package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.common.NullOption;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.TickPosition;
import com.hyjavacharts.model.highcharts.series.SeriesGauge;
import com.hyjavacharts.model.highcharts.yaxis.PlotBands;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;
import com.webonlineapp.hyjavachartsdemo11.services.RestService;

public class GaugeSeries extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
	    
		chartOptions.getChart()
			.setType(ChartType.GAUGE)
			.setPlotBorderWidth(0)
			.setPlotShadow(false)
			.setPlotBackgroundColor(null)
			.setPlotBackgroundImage(null)
			.getEvents().setLoad(new Function("runcounter = 0;"));

		chartOptions.getTitle().setText("Speedometer");
		chartOptions.getSubtitle().setText("(will stop after 60 seconds)");

		chartOptions.getPaneSingle()
			.setStartAngle(-90)
			.setEndAngle(89.9)
			.setBackground(null)
			.setCenterAsArrayString(Arrays.asList("50%", "75%"))
			.setSize("110%");

		YAxis yAxis = new YAxis();
		yAxis.setMin(0)
			.setMax(200)
			.setTickPixelInterval(72)
			.setTickPosition(TickPosition.INSIDE)
			.setTickLength(20)
			.setTickWidth(2)
			.setMinorTickInterval(NullOption.NULL_NUMBER)
			.getLabels().setDistance(20).getStyle().setFontSize("14px");
		
		yAxis.getTickColor().setColorValue("Highcharts.defaultOptions.chart.backgroundColor || '#FFFFFF'");
		
		yAxis.getPlotBands().add(new PlotBands().setFrom(0).setTo(120).setColor(new Color("#55BF3B")).setThickness(20));
		yAxis.getPlotBands().add(new PlotBands().setFrom(120).setTo(160).setColor(new Color("#DDDF0D")).setThickness(20));
		yAxis.getPlotBands().add(new PlotBands().setFrom(160).setTo(200).setColor(new Color("#DF5353")).setThickness(20));
		
		chartOptions.getYAxis().add(yAxis);
		
		SeriesGauge sg = new SeriesGauge();
		sg.setName("Speed").getTooltip().setValueSuffix(" km/h");
		sg.getDataLabels()
			.setFormat("{y} km/h")
			.setBorderWidth(0)
			.getStyle().setFontSize("16px");
		sg.getDataLabels()
			.getColor().setColorValue("(Highcharts.defaultOptions.title && Highcharts.defaultOptions.title.style && Highcharts.defaultOptions.title.style.color) || '#333333'");
		sg.getDial()
			.setRadius("80%").setBackgroundColor(new Color("gray"))
			.setBaseWidth(12).setBaseLength("0%").setRearLength("0%");
		sg.getPivot()
			.setBackgroundColor(new Color("gray")).setRadius(6);

		chartOptions.getSeries().add(sg);
		
		// Some of our example charts use a REST service to retrieve data.
		chartOptions.getData().setCsvURL(RestService.getURI() + "/GaugeSpeedCSVData")
			.setEnablePolling(true)
			.setDataRefreshRate(3)
			.setComplete(new Function("runcounter++; if (runcounter > 20) { chart.destroy(); }"));
		
		return highChart;
	}

}
