package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.LandmarkVerbosity;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class Instrument extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.SCATTER);
		
		chartOptions.getTitle().setText("Audio Chart (Instrument: vibraphone)").setAlign(HorizontalAlign.LEFT).setMargin(15);
		chartOptions.getLegend().setEnabled(false);
	    
	    chartOptions.getChart().getEvents().setRender(new Function("this.series[0].points.forEach(function (point) {if (point.x >= new Date('2022').getTime()) {point.ttBelow = true;}});"));

	    chartOptions.getAccessibility().setLandmarkVerbosity(LandmarkVerbosity.ONE).getPoint().setDescribeNull(false);
	    
	    YAxis yAxis = new YAxis();
	    yAxis.setTop("0%").setHeight("72%").setLineWidth(1).getTitle().setText("Revenue (millions)");
	    chartOptions.getYAxis().add(yAxis);
	    yAxis = new YAxis();
	    yAxis.setTop("85%").setHeight("15%").setOffset(0).getTitle().setText("Profit margin)");
	    yAxis.getLabels().setFormat("{text}%");
	    yAxis.getPlotBandsSingle().setFrom(0).setTo(30).setColor(new Color("#f6f7f8"));
	    chartOptions.getYAxis().add(yAxis);
	    
	    chartOptions.getXAxisSingle().setMinPadding(0.04).setMaxPadding(0.04).setType(AxisType.DATETIME)
	    	.getAccessibility().setRangeDescription("2017 to 2024");
	    
	    chartOptions.getPlotOptions().getSeries().getStates().getInactive().setEnabled(false);
	    chartOptions.getPlotOptions().getSeries().getMarker().setEnabled(false);
	    
	    chartOptions.getData().setCsv(getData());
 
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.setType(SeriesType.SPLINE).getSonification().getTracksSingle().setRoundToMusicalNotes(false);
		chartOptions.getSeries().add(seriesSpline);
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.setType(SeriesType.COLUMN).setYAxis(1).setPointWidth(30);
		chartOptions.getSeries().add(seriesColumn);

		chartOptions.getSonification().setDuration(9500).setAfterSeriesWait(1100);
		chartOptions.getSonification().getEvents().setBeforePlay(new Function("e.chart.sonification.speak('Revenue');", "e"));
		chartOptions.getSonification().getEvents().setOnSeriesEnd(new Function("if (e.series.index === 0) {e.series.chart.sonification.speak('Profit margin', {}, 150);}", "e"));
		chartOptions.getSonification().getDefaultInstrumentOptions().setInstrument("vibraphone").getMapping().setNoteDuration(400);
		chartOptions.getSonification().getDefaultInstrumentOptions().getMapping().setPlayDelay(750);
		
		this.setAudio(true);
		
		return highChart;
	}
	
	/**
	 * 
	 * @return
	 */
	private String getData() {
		return "Date,Revenue,Profit Margin\r\n"
				+ "2017-01-01,1210,3\r\n"
				+ "2017-02-01,1255,\r\n"
				+ "2017-03-01,1340,\r\n"
				+ "2017-04-01,1275,\r\n"
				+ "2017-05-01,1395,\r\n"
				+ "2017-06-01,1265,\r\n"
				+ "2017-07-01,1440,\r\n"
				+ "2017-08-01,1378,\r\n"
				+ "2017-09-01,1505,\r\n"
				+ "2017-10-01,1421,\r\n"
				+ "2017-11-01,1460,\r\n"
				+ "2017-12-01,1517,\r\n"
				+ "2018-01-01,1590,7\r\n"
				+ "2018-02-01,1610,\r\n"
				+ "2018-03-01,1650,\r\n"
				+ "2018-04-01,1725,\r\n"
				+ "2018-05-01,1680,\r\n"
				+ "2018-06-01,1743,\r\n"
				+ "2018-07-01,1780,\r\n"
				+ "2018-08-01,1832,\r\n"
				+ "2018-09-01,1900,\r\n"
				+ "2018-10-01,1865,\r\n"
				+ "2018-11-01,2020,\r\n"
				+ "2018-12-01,2084,\r\n"
				+ "2019-01-01,2150,5\r\n"
				+ "2019-02-01,2095,\r\n"
				+ "2019-03-01,2250,\r\n"
				+ "2019-04-01,2205,\r\n"
				+ "2019-05-01,2360,\r\n"
				+ "2019-06-01,2425,\r\n"
				+ "2019-07-01,2385,\r\n"
				+ "2019-08-01,2540,\r\n"
				+ "2019-09-01,2600,\r\n"
				+ "2019-10-01,2675,\r\n"
				+ "2019-11-01,2730,\r\n"
				+ "2019-12-01,2790,\r\n"
				+ "2020-01-01,2750,9\r\n"
				+ "2020-02-01,2820,\r\n"
				+ "2020-03-01,2850,\r\n"
				+ "2020-04-01,2750,\r\n"
				+ "2020-05-01,2840,\r\n"
				+ "2020-06-01,3000,\r\n"
				+ "2020-07-01,2980,\r\n"
				+ "2020-08-01,3050,\r\n"
				+ "2020-09-01,3220,\r\n"
				+ "2020-10-01,3480,\r\n"
				+ "2020-11-01,3560,\r\n"
				+ "2020-12-01,3640,\r\n"
				+ "2021-01-01,3720,11\r\n"
				+ "2021-02-01,3800,\r\n"
				+ "2021-03-01,3890,\r\n"
				+ "2021-04-01,3980,\r\n"
				+ "2021-05-01,4250,\r\n"
				+ "2021-06-01,4120,\r\n"
				+ "2021-07-01,4000,\r\n"
				+ "2021-08-01,4280,\r\n"
				+ "2021-09-01,4370,\r\n"
				+ "2021-10-01,4440,\r\n"
				+ "2021-11-01,4530,\r\n"
				+ "2021-12-01,4620,\r\n"
				+ "2022-01-01,4910,18\r\n"
				+ "2022-02-01,4900,\r\n"
				+ "2022-03-01,4890,\r\n"
				+ "2022-04-01,4940,\r\n"
				+ "2022-05-01,5070,\r\n"
				+ "2022-06-01,5100,\r\n"
				+ "2022-07-01,5060,\r\n"
				+ "2022-08-01,5240,\r\n"
				+ "2022-09-01,5420,\r\n"
				+ "2022-10-01,5520,\r\n"
				+ "2022-11-01,5400,\r\n"
				+ "2022-12-01,5430,\r\n"
				+ "2023-01-01,5310,20\r\n"
				+ "2023-02-01,5200,\r\n"
				+ "2023-03-01,5190,\r\n"
				+ "2023-04-01,5180,\r\n"
				+ "2023-05-01,5210,\r\n"
				+ "2023-06-01,5160,\r\n"
				+ "2023-07-01,5060,\r\n"
				+ "2023-08-01,5240,\r\n"
				+ "2023-09-01,5120,\r\n"
				+ "2023-10-01,5220,\r\n"
				+ "2023-11-01,5300,\r\n"
				+ "2023-12-01,5330,\r\n"
				+ "2024-01-01,5320,18";
	}

}
