package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.ArrayList;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Cursor;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesPie;
import com.hyjavacharts.model.highcharts.series.seriespie.Data;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class PieWithMonochromeFill extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
				
		chartOptions.getChart().setType(ChartType.PIE).setPlotBackgroundColor(null).setBorderWidth(null).setPlotShadow(false);
		chartOptions.getTitle().setText("Browser market shares in February, 2022").setAlign(HorizontalAlign.LEFT);
		chartOptions.getTooltip().setPointFormat("{series.name}: <b>{point.percentage:.1f}%</b>");

		chartOptions.getAccessibility().getPoint().setValueSuffix("%");
		
		chartOptions.getPlotOptions()
			.getPie()
				.setAllowPointSelect(true)
				.setCursor(Cursor.POINTER)
				.setBorderRadius(5)
				.setColors(getNewColors(chartOptions))
				.getDataLabels()
					.setEnabled(true)
					.setFormat("<b>{point.name}</b>: {point.percentage:.1f} %")
					.setDistance(-50)
					.getFilter().setProperty("percentage").setOperator(">").setValue(4);
		
		SeriesPie seriesPie = new SeriesPie();
		seriesPie.setName("Brands");
		seriesPie.setDataAsArrayObject(getSeriesData());
		chartOptions.getSeries().add(seriesPie);
		
		return highChart;
	}
	
	/**
	 * 
	 * @return
	 */
	private ArrayList<Data> getSeriesData() {
		ArrayList<Data> array = new ArrayList<Data>();

		array.add(new Data().setName("Chrome").setY(74.03));
		array.add(new Data().setName("Edge").setY(12.667));
		array.add(new Data().setName("Firefox").setY(4.96));
		array.add(new Data().setName("Safari").setY(2.49));
		array.add(new Data().setName("Internet Explorer").setY(2.31));
		array.add(new Data().setName("Other").setY(3.398));
		
		return array;
    }
	
	/**
	 * Create new colors list
	 * 
	 * @param chartOptions
	 * @return
	 */
	private List<Color> getNewColors(ChartOptions chartOptions) {
		String base = chartOptions.getColors().get(0).getColor();
		List<Color> newColors = new ArrayList<Color>();
		
		for (int i = 0; i < 10; i += 1) {
			double b = (new Double(i) - 3.0) / 7.0;
			newColors.add(new Color(base).brighten(b));
		}
		
		return newColors;
	}
}
