package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Stacking;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class RadialBar extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.COLUMN).setInverted(true).setPolar(true);
		chartOptions.getTitle().setText("Winter Olympic medals per existing country (TOP 5)").setAlign(HorizontalAlign.LEFT);
		chartOptions.getSubtitle()
			.setText("Source: <a href=\"https://en.wikipedia.org/wiki/All-time_Olympic_Games_medal_table\" target=\"_blank\">Wikipedia</a>")
			.setAlign(HorizontalAlign.LEFT);

		chartOptions.setColors(Arrays.asList(new Color("#FFD700"), new Color("#C0C0C0"), new Color("#CD7F32")));
		
		chartOptions.getTooltip().setOutside(true);
		chartOptions.getPaneSingle().setSize("85%").setInnerSize("20%").setEndAngle(270);
		
		chartOptions.getXAxisSingle()
			.setTickInterval(1)
			.setLineWidth(0)
			.setGridLineWidth(0)
			.setCategories(Arrays.asList(
				"Norway <span><img src=https://www.hyjavacharts.com/content/images/flag-no.png style=\"width: 15px; height: 12px;\"></span>",
				"United States <span><img src=https://www.hyjavacharts.com/content/images/flag-us.png style=\"width: 15px; height: 12px;\"></span>",
				"Germany <span><img src=https://www.hyjavacharts.com/content/images/flag-de.png style=\"width: 15px; height: 12px;\"></span>",
				"Austria <span><img src=https://www.hyjavacharts.com/content/images/flag-at.png style=\"width: 15px; height: 12px;\"></span>",
				"Canada <span><img src=https://www.hyjavacharts.com/content/images/flag-ca.png style=\"width: 15px; height: 12px;\"></span>"))
			.getLabels()
				.setAlign(HorizontalAlign.RIGHT).setUseHTML(true).setAllowOverlap(true)
				.setStep(1).setY(3).getStyle().setFontSize("13px");

		chartOptions.getYAxisSingle()
			.setLineWidth(0)
			.setTickInterval(25)
			.setReversedStacks(false)
			.setEndOnTick(true)
			.setShowLastLabel(true)
			.setGridLineWidth(0);

		chartOptions.getPlotOptions().getColumn()
			.setStacking(Stacking.NORMAL)
			.setBorderWidth(0)
			.setPointPadding(0)
			.setGroupPadding(0.15)
			.setBorderRadius("50%");
		
//		 series: [{
//		        name: 'Gold medals',
//		        data: [148, 113, 104, 71, 77]
//		    }, {
//		        name: 'Silver medals',
//		        data: [113, 122, 98, 88, 72]
//		    }, {
//		        name: 'Bronze medals',
//		        data: [124, 95, 65, 91, 76]
//		    }]
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.setName("Gold medals");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(148, 113, 104, 71, 77));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setName("Silver medals");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(113, 122, 98, 88, 72));
		chartOptions.getSeries().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.setName("Bronze medals");
		seriesColumn.setDataAsArrayNumber(Arrays.asList(124, 95, 65, 91, 76));
		chartOptions.getSeries().add(seriesColumn);
				
		return highChart;
	}
	
}
