package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Symbol;
import com.hyjavacharts.model.highcharts.constants.ZoomType;
import com.hyjavacharts.model.highcharts.series.SeriesScatter;
import com.webonlineapp.hyjavachartsdemo11.chartdata.ScatterPlotData;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class ScatterPlot extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.getChart().setType(ChartType.SCATTER)
			.getZooming().setType(ZoomType.XY);
		
		chartOptions.getTitle()
			.setText("Olympics athletes by height and weight")
			.setAlign(HorizontalAlign.LEFT);
		chartOptions.getSubtitle()
			.setText("Source: <a href=\"https://www.theguardian.com/sport/datablog/2012/aug/07/olympics-2012-athletes-age-weight-height\">The Guardian</a>")
			.setAlign(HorizontalAlign.LEFT);
		
		chartOptions.getXAxisSingle()
			.setStartOnTick(true)
			.setEndOnTick(true)
			.setShowLastLabel(true)
			.getTitle().setText("Height");
		chartOptions.getXAxisSingle()
			.getLabels().setFormat("{value} m");
			
		chartOptions.getYAxisSingle().getTitle().setText("Weight");
		chartOptions.getYAxisSingle().getLabels().setFormat("{value} kg");
		
		chartOptions.getLegend().setEnabled(true);

		chartOptions.getPlotOptions().getScatter()
			.getMarker()
				.setRadius(2.5)
				.setSymbol(Symbol.CIRCLE)
				.getStates()
					.getHover()
						.setEnabled(true)
						.setLineColor(new Color().setRGB(100, 100, 100));
		chartOptions.getPlotOptions().getScatter()
			.getStates()
				.getHover()
					.getMarker()
						.setEnabled(false);

		chartOptions.getTooltip().setPointFormat("Height: {point.x} m <br/> Weight: {point.y} kg");
		
		ScatterPlotData seriesData = new ScatterPlotData();
		
		SeriesScatter seriesScatter = new SeriesScatter();
		seriesScatter.setName("Basketball").setId("basketball").getMarker().setSymbol(Symbol.CIRCLE);
		seriesScatter.setColor(new Color().setRGBA(5,141,199,0.5));
		seriesScatter.getDataAsJsValue().setJsValue(seriesData.getSeriesData(1));
		chartOptions.getSeries().add(seriesScatter);
		
		seriesScatter = new SeriesScatter();
		seriesScatter.setName("Triathlon").setId("triathlon").getMarker().setSymbol(Symbol.TRIANGLE);
		seriesScatter.setColor(new Color().setRGBA(80,180,50,0.5));
		seriesScatter.getDataAsJsValue().setJsValue(seriesData.getSeriesData(2));
		chartOptions.getSeries().add(seriesScatter);
		
		seriesScatter = new SeriesScatter();
		seriesScatter.setName("Volleyball").setId("volleyball").getMarker().setSymbol(Symbol.SQUARE);
		seriesScatter.setColor(new Color().setRGBA(237,86,27,0.5));
		seriesScatter.getDataAsJsValue().setJsValue(seriesData.getSeriesData(3));
		chartOptions.getSeries().add(seriesScatter);
		
		return highChart;
	}
	
}
