package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.ArrayList;
import java.util.Calendar;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriesspline.Data;
import com.hyjavacharts.model.highcharts.yaxis.PlotLines;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class SplineUpdatingEachSecond extends DemoChartBase {
	private static final long serialVersionUID = 1L;
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getTime().setUseUTC(false);
		
		chartOptions.getChart().setType(ChartType.SPLINE).getEvents().setLoad(new Function(getLoadFunction()));
		chartOptions.getTitle().setText("Live random data");
		
		chartOptions.getAccessibility().getAnnounceNewData().setEnabled(true).setMinAnnounceInterval(15000)
			.setAnnouncementFormatter(new Function("if (newPoint) { return 'New point added. Value: ' + newPoint.y; } return false;", "allSeries", "newSeries", "newPoint"));

		chartOptions.getXAxis().add(new XAxis().setType(AxisType.DATETIME).setTickPixelInterval(150).setMaxPadding(0.1));
		
		YAxis yAxi = new YAxis();
		yAxi.getTitle().setText("Value");
		yAxi.getPlotLines().add(new PlotLines().setValue(0f).setWidth(1).setColor(new Color("#808080")));
		chartOptions.getYAxis().add(yAxi);

		chartOptions.getTooltip().setHeaderFormat("<b>{series.name}</b><br/>").setPointFormat("{point.x:%Y-%m-%d %H:%M:%S}<br/>{point.y:.2f}");

		chartOptions.getLegend().setEnabled(false);
		chartOptions.getExporting().setEnabled(true);
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.getLabel().setEnabled(false);
		seriesSpline.setType(SeriesType.SPLINE).setName("Random data").setColor(new Color().setColorValue("Highcharts.getOptions().colors[2]"));
		seriesSpline.setDataAsArrayObject(getSeriesData());
		chartOptions.getSeries().add(seriesSpline);
		
		return highChart;
	}

	/**
	 * 
	 * @return
	 */
	private ArrayList<Data> getSeriesData() {
		Calendar cal = Calendar.getInstance();

		ArrayList<Data> data = new ArrayList<Data>();
		long time = cal.getTime().getTime();
		int i;
		
		for (i = -19; i <= 0; i += 1) {
			data.add(new Data().setX(time + i * 1000).setY(Math.random()));
		}
		
		return data;
	}
	
	/**
	 * 
	 * @return
	 */
	private String getLoadFunction() {
		return "var series = this.series[0];" + 
				"intervalId = setInterval(function () {" + 
				"var x = (new Date()).getTime()," + 
				"y = Math.random();" + 
				"series.addPoint([x, y], true, true);" + 
			"}, 1000);";
	}

}
