package com.webonlineapp.hyjavachartsdemo11.examplecharts;

import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.General;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Key;
import com.hyjavacharts.model.highcharts.constants.Overflow;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.Symbol;
import com.hyjavacharts.model.highcharts.series.SeriesTreegraph;
import com.hyjavacharts.model.highcharts.series.seriestreegraph.Levels;
import com.webonlineapp.hyjavachartsdemo11.chartdata.TreegraphData;
import com.webonlineapp.hyjavachartsdemo11.charts.DemoChartBase;

public class TreegraphChart extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setSpacingBottom(30).setMarginRight(120);
		chartOptions.getTitle().setText("Phylogenetic language tree");

		SeriesTreegraph seriesTreegraph = new SeriesTreegraph();
		seriesTreegraph.setType(SeriesType.TREEGRAPH);
		seriesTreegraph.setKeys(Arrays.asList("parent", "id", "level")).setClip(false);
		seriesTreegraph.setDataAsJsValue(new General(new TreegraphData().getLanguageData()));
		
		seriesTreegraph.getMarker().setSymbol(Symbol.CIRCLE).setRadius(6).setFillColor(new Color("#ffffff")).setLineWidth(3);
		seriesTreegraph.getDataLabels()
			.setAlign(HorizontalAlign.LEFT).setPointFormat("{point.id}")
			.setX(24).setCrop(false).setOverflow(Overflow.ALLOW)
			.getStyle().setColor(new Color("#000000")).setTextOutline("3px #ffffff").setWhiteSpace("nowrap");

		Levels level = new Levels();
		level.setLevel(1).setLevelIsConstant(false);
		seriesTreegraph.getLevels().add(level);
		
		level = new Levels();
		level.setLevel(2).setColorByPoint(true);
		seriesTreegraph.getLevels().add(level);
		
		level = new Levels();
		level.setLevel(3).getColorVariation().setKey(Key.BRIGHTNESS).setTo(-0.5);
		seriesTreegraph.getLevels().add(level);
		
		level = new Levels();
		level.setLevel(4).getColorVariation().setKey(Key.BRIGHTNESS).setTo(0.5);
		seriesTreegraph.getLevels().add(level);
		
		level = new Levels();
		level.setLevel(6).getDataLabels().setX(10);
		level.getMarker().setRadius(4);
		seriesTreegraph.getLevels().add(level);

		chartOptions.getSeries().add(seriesTreegraph);
		
		this.setHeight("1200px");
		
		return highChart;
	}
	
}
