package com.webonlineapp.hyjavastockdemo11.components;

import java.util.Base64;
import java.util.Random;

import com.hyjavacharts.hyjavaimages.ImageException;
import com.hyjavacharts.hyjavaimages.ImageFormat;
import com.hyjavacharts.hyjavaimages.ImageGenerator;
import com.hyjavacharts.hyjavaimages.ImageOptions;
import com.hyjavacharts.hyjavaimages.LibraryInfo;
import com.hyjavacharts.hyjavaimages.LibraryType;
import com.hyjavacharts.hyjavaimages.PdfOptions;
import com.vaadin.flow.component.Html;
import com.vaadin.flow.component.Tag;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.button.ButtonVariant;
import com.vaadin.flow.component.html.Image;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.radiobutton.RadioButtonGroup;
import com.vaadin.flow.component.radiobutton.RadioGroupVariant;
import com.vaadin.flow.server.StreamResource;
import com.webonlineapp.hyjavastockdemo11.util.ServletUtil;

/**
 * Image generation is dependent on the HyJavaImages library.
 */

@Tag("div")
public class HighstockImageComponent extends VerticalLayout {
	private static final long serialVersionUID = 1L;
	
	
	/**
	 * 
	 * @param globalOptionsJs
	 * @param chartOptionsJs
	 */
	public void displayChartImage(String globalOptionsJs, String chartOptionsJs, boolean highcharts) {
		removeAll();
		
		add(getDemoText());
		
		RadioButtonGroup<String> imageFormatGroup = new RadioButtonGroup<>();
		imageFormatGroup.setLabel("Format");
		imageFormatGroup.setItems("png", "jpeg", "webp", "pdf");
		imageFormatGroup.addThemeVariants(RadioGroupVariant.LUMO_VERTICAL);
		imageFormatGroup.setValue("png");
		add(imageFormatGroup);
		
		RadioButtonGroup<String> resolutionGroup = new RadioButtonGroup<>();
		resolutionGroup.setLabel("Resolution");
		resolutionGroup.setItems("800 x 600", "1600 x 1200", "3200 x 2400");
		resolutionGroup.addThemeVariants(RadioGroupVariant.LUMO_VERTICAL);
		resolutionGroup.setValue("800 x 600");
		add(resolutionGroup);
		
		imageFormatGroup.addValueChangeListener(ComponentValueChangeEvent -> {
			if (imageFormatGroup.getValue().equals("pdf")) {
				resolutionGroup.setEnabled(false);
			}
			else {
				resolutionGroup.setEnabled(true);
			}
		});
		
		Button exportButton = new Button("Generate Chart Image");
		exportButton.addThemeVariants(ButtonVariant.LUMO_PRIMARY);
		add(exportButton);

		exportButton.addClickListener(clickEvent -> {
			Random rand = new Random();
			removeAll();

			boolean pdf = false;
			
			ImageFormat imageFormat = null;
			String format = imageFormatGroup.getValue();
			
			if (format.equals("png")) {
				imageFormat = ImageFormat.PNG;
			}
			else if (format.equals("jpeg")) {
				imageFormat = ImageFormat.JPEG;
			}
			else if (format.equals("webp")) {
				imageFormat = ImageFormat.WEBP;
			}
			else {
				pdf = true;
			}
			
			Number scale = 1;
			
			if (!pdf) {
				String resolution = resolutionGroup.getValue();
				if (resolution.equals("1600 x 1200")) {
					scale = 2;
				}
				else if (resolution.equals("3200 x 2400")) {
					scale = 4;
				}
			}

	        EmbeddedPdf chartPdf = null;
			Image chartImage = null;
			
    		ImageGenerator img = new ImageGenerator();
    		img.setChartDivSize("800px", "600px");
    		img.setCSSExternal(ServletUtil.getLocation() + "/css/gui.css", ServletUtil.getLocation() + "/css/popup.css");
     		
    		img.setJavaScriptAlternate(highcharts ? LibraryType.HIGHCHARTS : LibraryType.HIGHCHARTS_STOCK, 
    					ServletUtil.getLocation() + "js/hs-demo.js");
    		
    		try {
    			String base64;
    			
    			if (pdf) {
    				base64 = img.toBase64PDF(globalOptionsJs, chartOptionsJs, 
    								new PdfOptions().setLandscape(true).setPrintBackground(true).setScale(scale));
    				byte [] imageBytes = Base64.getDecoder().decode(base64);
    				StreamResource resource = new StreamResource("image" + rand.nextInt(999999999) + ".pdf", 
    	    				new ChartImageStream(imageBytes));
    				
    				chartPdf = new EmbeddedPdf(resource);
    			}
    			else {
					base64 = img.toBase64Image(globalOptionsJs, chartOptionsJs, 
												new ImageOptions().setFormat(imageFormat).setScale(scale));
					byte [] imageBytes = Base64.getDecoder().decode(base64); 
					StreamResource resource = new StreamResource("image" + rand.nextInt(999999999) + 
							(imageFormat == ImageFormat.PNG ? ".png" : imageFormat == ImageFormat.JPEG ? ".jpeg" : ".webp"), 
		    				new ChartImageStream(imageBytes));
					
					chartImage = new Image(resource, "");
    			}

			} catch (ImageException e) {
				e.printStackTrace();
			}
     		
    		if (pdf) {
    			add(chartPdf);
    		}
    		else {
    			chartImage.setWidth("800px");
    			chartImage.setHeight("600px");
        		add(chartImage);
    		}
     	});
	}
	
	/**
	 * 
	 * @return
	 */
	private Html getDemoText() {
		String text = 
			"<div><h4>HyJavaImages v" + LibraryInfo.getHyJavaImagesAPIVersion() + " Library Demonstration</h4>" + 
			"<p>Select an example chart from the menu on the left and press the Generate Chart Image button.</p>" + 
			"<p>In this demo the <b>HyJavaImages</b> library generates the chart image from Highcharts Stock chart options displayed in the Chart Options tab above." + 
			"<br>All processing occurs on the server. No Javascript is executed on the client browser.</p></div>";
		
		return new Html(text);
	}
	
}
