package com.webonlineapp.hyjavastockdemo11.components;

import com.vaadin.flow.component.AbstractSinglePropertyField;
import com.vaadin.flow.component.Tag;
import com.vaadin.flow.component.dependency.JsModule;
import com.vaadin.flow.component.dependency.NpmPackage;

@Tag("paper-toggle-button")
@JsModule("@polymer/paper-toggle-button/paper-toggle-button.js")
@NpmPackage(value = "@polymer/paper-toggle-button", version = "3.0.1")
public class PaperToggleButton extends AbstractSinglePropertyField<PaperToggleButton, Boolean> {
    private static final long serialVersionUID = 1L;

    
    /**
     * Construct with no label.
     */
    public PaperToggleButton() {
    	super("checked", false, false);
    	this.getElement().getStyle().set("--paper-toggle-button-checked-button-color", "var(--lumo-primary-color)");
    }
    
    /**
     * Construct with the given label.
     * @param label the toggle button label.
     */
    public PaperToggleButton(String label) {
    	this();
    	setLabel(label);
    }
    
    /**
     * Construct with the given label and setting.
     * @param label the toggle button label.
     * @param setting the initial on/off setting for the toggle button.
     */
    public PaperToggleButton(String label, Boolean setting) {
    	this();
    	setLabel(label);
    	setValue(setting);
    }
    
    /**
     * Set the toggle button label.
     * @param label the toggle button label.
     */
    public void setLabel(String label) {
    	getElement().setText(label);
    }
    
    /**
     * Get the toggle button label.
     * @return the toggle button label.
     */
    public String getLabel() {
    	return getElement().getText();
    }
    
    /**
     * Indicate if the toggle setting if on/off. 
     * @return indicate if the toggle setting if on/off. 
     */
    public Boolean isToggleOn() {
    	return getValue();
    }
    
    /**
     * Sets the toggle on/off.
     * @param setting the toggle on/off setting.
     */
    public void setToggleOn(Boolean setting) {
    	setValue(setting);
    }

}