package com.webonlineapp.hyjavastockdemo11.examplecharts;

import jakarta.ws.rs.client.WebTarget;

import com.hyjavastock.chart.Highstock;
import com.hyjavastock.model.common.Color;
import com.hyjavastock.model.highstock.ChartOptions;
import com.hyjavastock.model.highstock.YAxis;
import com.hyjavastock.model.highstock.constants.FlagsShape;
import com.hyjavastock.model.highstock.constants.SeriesType;
import com.hyjavastock.model.highstock.series.SeriesFlags;
import com.hyjavastock.model.highstock.series.SeriesLine;
import com.hyjavastock.model.highstock.series.seriesflags.Data;
import com.webonlineapp.hyjavastockdemo11.charts.DemoChartBase;
import com.webonlineapp.hyjavastockdemo11.services.RestService;

public class FlagsShapesAndColors extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highstock configure() {
		Highstock highStock = new Highstock();
		ChartOptions chartOptions = highStock.getChartOptions();
		
		chartOptions.getStockTools().getGui().setEnabled(false);
	    
		chartOptions.getTitle().setText("USD to EUR exchange rate");
		chartOptions.getRangeSelector().setSelected(4);

		YAxis yAxi = new YAxis();
		yAxi.getTitle().setText("Exchange rate");
		chartOptions.getYAxis().add(yAxi);
		
		SeriesLine seriesLine = new SeriesLine();
		seriesLine.setName("USD to EUR").setId("dataseries");
		seriesLine.getTooltip().setValueDecimals(4);
		seriesLine.getDataAsJsValue().setJsValue(getSeriesData());
		chartOptions.getSeries().add(seriesLine);
		
		SeriesFlags seriesFlags = new SeriesFlags();
		seriesFlags.setType(SeriesType.FLAGS)
			.setOnSeries("dataseries")
			.setShape(FlagsShape.SQUAREPIN)
			.setWidth(16);
		seriesFlags.getDataAsArrayObject()
			.add(new Data().setX(new Long("1487721600000")).setTitle("A").setText("Shape: \"squarepin\""));
		seriesFlags.getDataAsArrayObject()
			.add(new Data().setX(new Long("1493337600000")).setTitle("A").setText("Shape: \"squarepin\""));
		chartOptions.getSeries().add(seriesFlags);
		
		seriesFlags = new SeriesFlags();
		seriesFlags.setType(SeriesType.FLAGS)
			.setShape(FlagsShape.CIRCLEPIN)
			.setWidth(16);
		seriesFlags.getDataAsArrayObject()
			.add(new Data().setX(new Long("1488326400000")).setTitle("B").setText("Shape: \"circlepin\""));
		seriesFlags.getDataAsArrayObject()
			.add(new Data().setX(new Long("1491004800000")).setTitle("B").setText("Shape: \"circlepin\""));
		chartOptions.getSeries().add(seriesFlags);
		
		seriesFlags = new SeriesFlags();
		seriesFlags.setType(SeriesType.FLAGS)
			.setOnSeries("dataseries")
			.setWidth(16);
		seriesFlags.setColor(chartOptions.getColors().get(0)).setFillColor(chartOptions.getColors().get(0));
		seriesFlags.getStyle().setColor(new Color("white"));
		seriesFlags.getStates().getHover().setFillColor(new Color("#395C84"));
		seriesFlags.getDataAsArrayObject()
			.add(new Data().setX(new Long("1489104000000")).setTitle("C").setText("Shape: \"flag\""));
		seriesFlags.getDataAsArrayObject()
			.add(new Data().setX(new Long("1491868800000")).setTitle("C").setText("Shape: \"flag\""));
		chartOptions.getSeries().add(seriesFlags);
		
		return highStock;
	}
	
	/**
	 * 
	 * @return
	 */
	private String getSeriesData() {
		// Some of our example charts use a REST service to retrieve data.
		// REST service returns json data in format [ [date, exchange-rate], [...] ]
		WebTarget webTarget = new RestService().getWebTarget();
		
		return webTarget.path("HighstockUsdEurJson").request().get(String.class);
	}
	
}