package com.webonlineapp.hyjavastockdemo11.examplecharts;

import com.hyjavastock.chart.Highstock;
import com.hyjavastock.model.common.Color;
import com.hyjavastock.model.common.Function;
import com.hyjavastock.model.highstock.ChartOptions;
import com.hyjavastock.model.highstock.constants.HorizontalAlign;
import com.hyjavastock.model.highstock.constants.PointGroupingAlgorithm;
import com.hyjavastock.model.highstock.constants.SonificationOrder;
import com.hyjavastock.model.highstock.constants.TrackType;
import com.hyjavastock.model.highstock.constants.VerticalAlign;
import com.hyjavastock.model.highstock.series.SeriesLine;
import com.webonlineapp.hyjavastockdemo11.charts.DemoChartBase;
import com.webonlineapp.hyjavastockdemo11.services.RestService;

public class Soundscape extends DemoChartBase {
	private static final long serialVersionUID = 1L;

	public Highstock configure() {
		Highstock highStock = new Highstock();
		ChartOptions chartOptions = highStock.getChartOptions();
		
		chartOptions.getStockTools().getGui().setEnabled(false);
	    
		chartOptions.getTitle().setText("JFK Airport Climate Data for 2013 - Wind Speed").setAlign(HorizontalAlign.LEFT);
		chartOptions.getSubtitle().setText("Source: data.world").setAlign(HorizontalAlign.LEFT);
		
		chartOptions.getChart().getEvents().setLoad(new Function(" lastMonth = null; "));
		
		chartOptions.getSonification()
			.setMasterVolume(0.5).setDuration(25000).setOrder(SonificationOrder.SIMULTANEOUS).setShowTooltip(false)
			.getPointGrouping().setGroupTimespan(250).setAlgorithm(PointGroupingAlgorithm.MINMAX);
		
		chartOptions.getSonification().getDefaultInstrumentOptions().setShowPlayMarker(false)
			.getMapping().getPitchAsObject().setMin("a3").setMax("a7");
		
		chartOptions.getSonification().getEvents().setBeforeUpdate(new Function(" lastMonth = null; "));
		
		chartOptions.getSonification()
			.getGlobalContextTracksSingle()
				.setType(TrackType.SPEECH).setValueInterval(1000 * 60 * 60 * 24)
				.getMapping()
					.setRate(2.5).setVolume(1)
					.setText(new Function("var date = new Date(context.value); return date.toLocaleString('en-US', { month: 'long' });", "context"));
		
		chartOptions.getSonification().getGlobalContextTracksSingle()
			.setActiveWhen(new Function("var month = new Date(context.value).getMonth(), shouldSpeak = month !== lastMonth; lastMonth = month; return shouldSpeak;", "context"));
		
		chartOptions.getRangeSelector().setSelected(1).setVerticalAlign(VerticalAlign.BOTTOM);

		chartOptions.getData()
			.setCsvURL(RestService.getURI() + "/WindspeedCSVData")
			.setParsed(new Function("var i = columns[0].length; while (i--) { columns[0][i] = new Date(columns[0][i]).getTime(); }", "columns"));
		
		chartOptions.getXAxisSingle().setMinRange(1000 * 60 * 60 * 24 * 10)
			.getCrosshairAsObject().setColor(new Color("rgba(70, 120, 160, 0.7)")).setWidth(20);
		
		chartOptions.getYAxisSingle().setOpposite(false).setGridLineWidth(0)
			.getLabels().setFormat("{text} mph");
		chartOptions.getYAxisSingle().getAccessibility().setDescription("Wind speed");
		
		SeriesLine seriesLine = new SeriesLine();
		seriesLine.setColor(new Color("#577")).setOpacity(0.75).setShowInNavigator(true)
			.getSonification().getPointGrouping().setGroupTimespan(100);
		seriesLine.getSonification().getTracksSingle().setInstrument("wind").setShowPlayMarker(true);
		chartOptions.getSeries().add(seriesLine);
		
		this.setAudio(true);
		
		return highStock;
	}

}