package com.webonlineapp;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.hyjavaapex.chart.Apexchart;
import com.hyjavacharts.chart.Highchart;
import com.hyjavastock.chart.Highstock;
import com.webonlineapp.charts.ApexChartsBasicColumn;
import com.webonlineapp.charts.HighchartsLine;
import com.webonlineapp.charts.HighchartsPie;
import com.webonlineapp.charts.HighstockColumn;

/*
 * A simple proof of concept example application to show how to integrate
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library 
 *   
 * in a JSP application.
 * 
 * The Charts available are: 
 *   Highcharts line and pie charts
 *   Highcharts Stock column chart
 *   ApexCharts basic column chart
 *   
 * NOTE: We are not experts using JSP's so there will no doubt be better ways to accomplish the same thing.
 * 
 */
@WebServlet("/")
public final class DemoServlet extends HttpServlet {
	private static final long serialVersionUID = 1L;


    /**
     * 
     */
    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {

        handleRequest(req, resp);
    }

    /**
     * 
     */
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {

        handleRequest(req, resp);
    }

    /**
     * 
     * @param req
     * @param resp
     * @throws ServletException
     * @throws IOException
     */
    private void handleRequest(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {
     	
    	if (req.getServletPath().equals("/displaychart")) {
	     	String reqChart = req.getParameter("chartName") == null ? "Highcharts Line Chart" : req.getParameter("chartName");
	    	req.setAttribute("chartName", reqChart);
	    	
	    	String globalOptionsJs = "";
	    	String chartOptionsJs = "";
	    	
	    	if (reqChart.equals("Highstock Column Chart")) {
	    		Highstock hs = new HighstockColumn().configure();
	    		chartOptionsJs = hs.chartOptionsToJs();
	    		
	    		req.setAttribute("globalOptions", globalOptionsJs);
		        req.setAttribute("chartOptions", chartOptionsJs);
		 
		        req.getRequestDispatcher("/highstockdemo.jsp").forward(req, resp);
	    	}
	    	else if (reqChart.equals("ApexCharts Column Chart")) {
	    		Apexchart apexchart = new ApexChartsBasicColumn().configure();
	    		chartOptionsJs = apexchart.chartOptionsToJs();
	
		        req.setAttribute("chartOptions", chartOptionsJs);
		 
		        req.getRequestDispatcher("/apexchartsdemo.jsp").forward(req, resp);
	    	}
	    	else {
				Highchart hc = null;
				
				if (reqChart.equals("Highcharts Line Chart")) {
		    		hc = new HighchartsLine().configure();
		    		chartOptionsJs = hc.chartOptionsToJs();
		    	}
		    	else {
		    		hc = new HighchartsPie().configure();
		    		chartOptionsJs = hc.chartOptionsToJs();
		    	}
		    	
		    	req.setAttribute("globalOptions", globalOptionsJs);
		        req.setAttribute("chartOptions", chartOptionsJs);
		 
		        req.getRequestDispatcher("/highchartsdemo.jsp").forward(req, resp);
	    	}
	    }
    	else {
    		req.getRequestDispatcher("/home.jsp").forward(req, resp);
    	}
    }

}
